
/* -------------------------------------------------------------------------- */

/*

pgplotpackage_tclwrap.c

United States Naval Observatory
USNO/NRL Optical Interferometer
3450 Massachusetts Avenue, NW
Washington, DC  20392-5420

Subsystem:
----------
ptcl

Description:
------------
This file contains tcl wrapper functions (written in C) which call functions
from the PGPLOT plotting package.

Functions:
----------
PGPLOT_TclWrappers, Tcl_pgarro, Tcl_pgask, Tcl_pgband, Tcl_pgbbuf, Tcl_pgbeg,
Tcl_pgbin, Tcl_pgbox, Tcl_pgcirc, Tcl_pgcurs, Tcl_pgdraw, Tcl_pgebuf, Tcl_pgend,
Tcl_pgenv, Tcl_pgeras, Tcl_pgerrb, Tcl_pgerrx, Tcl_pgerrx2, Tcl_pgerry,
Tcl_pgerry2, Tcl_pgetxt, Tcl_pgfunt, Tcl_pgfunx, Tcl_pgfuny, Tcl_pghist,
Tcl_pgiden, Tcl_pglab, Tcl_pglcur, Tcl_pgldev, Tcl_pglen, Tcl_pgline,
Tcl_pgmove, Tcl_pgmtxt, Tcl_pgncur, Tcl_pgnumb, Tcl_pgolin, Tcl_pgpage,
Tcl_pgpanl, Tcl_pgpap, Tcl_pgpnts, Tcl_pgpoly, Tcl_pgpt, Tcl_pgptxt, Tcl_pgqah,
Tcl_pgqcf, Tcl_pgqch, Tcl_pgqci, Tcl_pgqcir, Tcl_pgqcol, Tcl_pgqcr, Tcl_pgqcs,
Tcl_pgqfs, Tcl_pgqinf, Tcl_pgqitf, Tcl_pgqls, Tcl_pgqlw, Tcl_pgqpos, Tcl_pgqtbg,
Tcl_pgqtxt, Tcl_pgqvp, Tcl_pgqvsz, Tcl_pgqwin, Tcl_pgrect, Tcl_pgrnd,
Tcl_pgrnge, Tcl_pgsah, Tcl_pgsave, Tcl_pgscf, Tcl_pgsch, Tcl_pgsci, Tcl_pgscir,
Tcl_pgscr, Tcl_pgscrn, Tcl_pgsfs, Tcl_pgshls, Tcl_pgsitf, Tcl_pgsls, Tcl_pgslw,
Tcl_pgstbg, Tcl_pgsubp, Tcl_pgsvp, Tcl_pgswin, Tcl_pgtbox, Tcl_pgtext,
Tcl_pgunsa, Tcl_pgupdt, Tcl_pgvsiz, Tcl_pgvstd, Tcl_pgwnad.

Modification history:
---------------------
1994 Apr 15 - Nicholas Elias, USNO/AD5
              File created with function Tcl_pgbeg( ).
1994 Apr 17 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgadvance( ), Tcl_pgend( ), Tcl_pgenv( ), 
              Tcl_pgerrx( ), Tcl_pgerry( ), Tcl_pglab( ), Tcl_pgline( ), 
              and Tcl_pgpoint( ) added.
1994 May 07 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgerrx2( ), Tcl_pgerry2( ), and Tcl_pgsci( ) added.
1994 May 09 - Nicholas Elias, USNO/AD5
              Function Tcl_pgrnge( ) added.
1994 Jun 03 - Nicholas Elias, USNO/AD5
              Function Tcl_pgmtxt( ) added.
1995 May 02 - Nicholas Elias, USNO/AD5
              Function Tcl_pgwnad( ) added.
1995 May 25 - Nicholas Elias, USNO/AD5
	      Function Tcl_pghist( ) added.
1995 Aug 12 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgask( ), Tcl_pgiden( ), Tcl_pgsave( ),
              Tcl_pgunsa( ), and Tcl_pgupdt( ) added.
1995 Aug 28 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgqah( ), Tcl_pgqcf( ), Tcl_pgqch( ), Tcl_pgqci( ),
              Tcl_pgqcir( ), Tcl_pgqcol( ), and Tcl_pgqcr( ) added.
1995 Sep 15 - Nicholas Elias, USNO/AD5
              Function PGPLOT_TclWrappers( ) added.
1995 Sep 15 - Nicholas Elias, USNO/AD5
              Function Tcl_pgadvance( ) changed to Tcl_pgpage( ).  Both the
              pgpage and pgadvance tcl commands are registered to Tcl_pgpage( ).
1995 Sep 15 - Nicholas Elias, USNO/AD5
              Function Tcl_pgpoint( ) changed to Tcl_pgpt( ).  Both the pgpt and
              pgpoint tcl commands are registered to Tcl_pgpt( ).
1995 Nov 01 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgarro( ), Tcl_pgband( ), Tcl_pgbbuf( ), and
              Tcl_pgebuf( ) added.
1995 Nov 03 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgbin( ), Tcl_pgbox( ), Tcl_pgcirc( ),
              Tcl_pgeras( ), Tcl_pgrnd( ), and Tcl_pgsfs( ) added.
1995 Nov 04 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgscf( ), Tcl_pgsch( ), Tcl_pgsitf( ), Tcl_pgsls( ),
              Tcl_pgslw( ), and Tcl_pgstbg( ) added.
1995 Nov 05 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgfunt( ), Tcl_pgfunx( ), and Tcl_pgfuny( ) added.
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgptxt( ), Tcl_pgqcs( ), Tcl_pgqfs( ),
              Tcl_pgqinf( ), Tcl_pgqitf( ), Tcl_pgqls( ), Tcl_pgqlw( ),
              Tcl_pgqpos( ), Tcl_pgqtbg( ), Tcl_pgqtxt( ), Tcl_pgqvp( ),
              Tcl_pgqvsz( ), Tcl_pgqwin( ), and Tcl_pgrect( ) added.
1995 Nov 07 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgsah( ), Tcl_pgscir( ), Tcl_pgscr( ),
	      Tcl_pgscrn( ), Tcl_pgshls( ), Tcl_pgsubp( ), Tcl_pgsvp( ), and
	      Tcl_pgswin( ) added.
1995 Nov 09 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgcurs and Tcl_pgerrb( ) added.
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgdraw( ), Tcl_pgetxt( ), Tcl_pglcur( ),
              Tcl_pgldev( ), Tcl_pglen( ), Tcl_pgmove, Tcl_pgncur( ),
              Tcl_pgolin( ), Tcl_pgpand( ), Tcl_pgpap( ), Tcl_pgpnts( ), and
              Tcl_pgpoly( ) added.
1995 Nov 11 - Nicholas Elias, USNO/AD5
              Functions Tcl_pgnumb( ), Tcl_pgtbox( ), Tcl_pgtext( ),
              Tcl_pgvsiz( ), and Tcl_pgvstd( ) added.
1997 May 03 - Nicholas Elias, USNO/AD5
              All functions now return TCL_OK when successful and TCL_ERROR when
              an error occurs.

*/

/* -------------------------------------------------------------------------- */

/* Defines */

#define NUM_BIN_PGPLOT 10000   /* This is the maximum number of bins permitted \
                                  by PGPLOT */
#define NUM_DATA_PGPLOT 100000 /* This is the maximum number of data points \
                                  permitted by PGPLOT */

/* -------------------------------------------------------------------------- */

/* Includes */

#include <stdio.h>                 /* Standard I/O */
#include <stdlib.h>                /* Standard library */
#include <math.h>                  /* Math */
#include <string.h>                /* String */
#include <ctype.h>                 /* Character type */

#include "tcl.h"                   /* tcl */

#include "macro.h"                 /* Math macros */
#include "memory2.h"               /* Memory allocation/deallocation macros */
#include "tcl_altfunc.h"           /* Tcl alternate function prototypes */

#include "pgplot.h"                /* PGPLOT function prototypes */
#include "pgplot2.h"               /* PGPLOT additional function prototypes */
#include "pgplotpackage_tclwrap.h" /* PGPLOT function tcl wrapper prototypes */

/* -------------------------------------------------------------------------- */

/* Declare the global variables */

int iNumBinPGPLOT = NUM_BIN_PGPLOT;   /* This is the int variable which contains
                                         the maximum number of bins allowed for
                                         PGPLOT functions */
int iNumDataPGPLOT = NUM_DATA_PGPLOT; /* This is the int variable which contains
                                         the maximum number of data allowed for
                                         PGPLOT functions */

/* -------------------------------------------------------------------------- */

/*

PGPLOT_TclWrappers

Description:
------------
This function registers functions from the libpgplot*.* library and pgplot2.c
file into tcl.

Inputs:
-------
*pmtInterp - This is the pointer to the Tcl_Interp variable which contains the
	     tcl interpreter.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp variable which contains the
	     tcl interpreter.

Modification history:
---------------------
1995 Sep 15 - Nicholas Elias, USNO/AD5
	      Function created.

*/

/* -------------------------------------------------------------------------- */

int PGPLOT_TclWrappers( Tcl_Interp *pmtInterp )
{

  /* Register the C functions as tcl commands */
  
  Tcl_CreateCommand( pmtInterp, "pgarro", Tcl_pgarro, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgask", Tcl_pgask, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgband", Tcl_pgband, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgbbuf", Tcl_pgbbuf, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgbeg", Tcl_pgbeg, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgbin", Tcl_pgbin, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgbox", Tcl_pgbox, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgcirc", Tcl_pgcirc, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgclos", Tcl_pgclos, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgcurs", Tcl_pgcurs, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgdraw", Tcl_pgdraw, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgebuf", Tcl_pgebuf, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgetxt", Tcl_pgetxt, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgend", Tcl_pgend, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgenv", Tcl_pgenv, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgeras", Tcl_pgeras, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgerrb", Tcl_pgerrb, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgerrx", Tcl_pgerrx, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgerrx2", Tcl_pgerrx2, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgerry", Tcl_pgerry, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgerry2", Tcl_pgerry2, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgfunt", Tcl_pgfunt, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgfunx", Tcl_pgfunx, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgfuny", Tcl_pgfuny, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pghist", Tcl_pghist, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgiden", Tcl_pgiden, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pglab", Tcl_pglab, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pglcur", Tcl_pglcur, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgldev", Tcl_pgldev, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pglen", Tcl_pglen, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgline", Tcl_pgline, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgmove", Tcl_pgmove, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgmtxt", Tcl_pgmtxt, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgncur", Tcl_pgncur, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgnumb", Tcl_pgnumb, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgolin", Tcl_pgolin, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgopen", Tcl_pgopen, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgpage", Tcl_pgpage, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgpanl", Tcl_pgpanl, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgpap", Tcl_pgpap, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgpnts", Tcl_pgpnts, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgpoly", Tcl_pgpoly, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgpt", Tcl_pgpt, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgptxt", Tcl_pgptxt, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqah", Tcl_pgqah, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqcf", Tcl_pgqcf, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqch", Tcl_pgqch, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqci", Tcl_pgqci, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqcir", Tcl_pgqcir, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqcol", Tcl_pgqcol, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqcr", Tcl_pgqcr, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqcs", Tcl_pgqcs, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqfs", Tcl_pgqfs, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqhs", Tcl_pgqhs, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqid", Tcl_pgqid, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqinf", Tcl_pgqinf, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqitf", Tcl_pgqitf, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqls", Tcl_pgqls, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqlw", Tcl_pgqlw, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqpos", Tcl_pgqpos, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqtbg", Tcl_pgqtbg, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqtxt", Tcl_pgqtxt, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqvp", Tcl_pgqvp, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqvsz", Tcl_pgqvsz, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgqwin", Tcl_pgqwin, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgrect", Tcl_pgrect, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgrnd", Tcl_pgrnd, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgrnge", Tcl_pgrnge, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgsah", Tcl_pgsah, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgsave", Tcl_pgsave, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgscf", Tcl_pgscf, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgsch", Tcl_pgsch, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgsci", Tcl_pgsci, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgscir", Tcl_pgscir, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgscr", Tcl_pgscr, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgscrn", Tcl_pgscrn, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgsfs", Tcl_pgsfs, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgshls", Tcl_pgshls, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgshs", Tcl_pgshs, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgsitf", Tcl_pgsitf, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgslct", Tcl_pgslct, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgsls", Tcl_pgsls, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgslw", Tcl_pgslw, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgstbg", Tcl_pgstbg, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgsubp", Tcl_pgsubp, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgsvp", Tcl_pgsvp, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgswin", Tcl_pgswin, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgtbox", Tcl_pgtbox, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgtext", Tcl_pgtext, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgvsiz", Tcl_pgvsiz, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgvstd", Tcl_pgvstd, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgunsa", Tcl_pgunsa, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgupdt", Tcl_pgupdt, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgwnad", Tcl_pgwnad, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
      
  Tcl_CreateCommand( pmtInterp, "pgadvance", Tcl_pgpage, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgbegin", Tcl_pgbeg, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pglabel", Tcl_pglab, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgmtext", Tcl_pgmtxt, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgpaper", Tcl_pgpap, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
  Tcl_CreateCommand( pmtInterp, "pgpoint", Tcl_pgpt, (ClientData*) NULL,
      (Tcl_CmdDeleteProc*) NULL );
      
  
  /* Return TCL_OK to the calling function */
  
  return( TCL_OK );

}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgarro

Description:
------------
This function creates a tcl command that draws an arrow.  It must be registered
with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgarro command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgarro command itself).
               asArgV[0] contains "pgarro", asArgV[1] contains the x world
               coordinate of the tail, asArgV[2] contains the y world coordinate
               of the tail, asArgV[3] contains the x world coordinate of the
               head, and asArgV[4] contains the y world coordinate of the head.
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 01 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgarro( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult; /* This is the int variable which contains the result of "Tcl_*"
                  function calls */
  
  real rXHead; /* This is the real variable which contains the x world
                  coordinate of the head */
  real rXTail; /* This is the real variable which contains the x world
                  coordinate of the tail */
  real rYHead; /* This is the real variable which contains the y world
                  coordinate of the head */
  real rYTail; /* This is the real variable which contains the y world
                  coordinate of the tail */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pgarro: Invalid number of arguments...";
    return( TCL_ERROR );
  }


  /* Get the arguments for pgarro( ) */

  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rXTail );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgarro: Invalid x world coordinate (tail)...";
    return( TCL_ERROR );
  }

  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rYTail );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgarro: Invalid y world coordinate (tail)...";
    return( TCL_ERROR );
  }

  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rXHead );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgarro: Invalid x world coordinate (head)...";
    return( TCL_ERROR );
  }

  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rYHead );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgarro: Invalid y world coordinate (head)...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgarro( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgarro( rXTail, rYTail, rXHead, rYHead );
#else
  PGARRO( rXTail, rYTail, rXHead, rYHead );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";  

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgask

Description:
------------
This function creates a tcl command that changes the prompt state in PGPLOT.  It
must be registered with a tcl (or tk or [incr tcl]) int main( ) function to be
used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgask command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgask command itself).
               asArgV[0] contains "pgask" and asArgV[1] contains the prompt
               state flag (0 or 1).
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 12 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgask( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;    /* This is the int variable which contains the result of
                     "Tcl_*" function calls */

  integer liFlag; /* This is the integer variable which contains the prompt
                     state flag (it must be 0 or 1) */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgask: Invalid number of arguments...";
    return( TCL_ERROR );
  }


  /* Get the argument for pgask( ) */

  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liFlag );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgask: Invalid prompt state flag...";
    return( TCL_ERROR );
  }
  
  if ( ( liFlag != 0 ) && ( liFlag != 1 ) )
  {
    pmtInterp->result = "!! Tcl_pgask: Invalid prompt state flag...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgask( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgask( liFlag );
#else
  PGASK( liFlag );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgband

Description:
------------
This function creates a tcl command which reads the cursor position and letter
typed by the user and performs cursor related tasks depending on the mode.  It
must be registered with a tcl (or tk or [incr tcl]) int main( ) function to be
used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgband command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgband command itself).
               asArgV[0] contains "pgband", asArgV[1] contains the mode,
               asArgV[2] contains the position flag, asArgV[3] contains the x
               world coordinate of the anchor point, asArgV[4] contains the y
               world coordinate of the anchor point, asArgV[5] contains the x
               world coordinate of the cursor (optional), and asArgV[6] contains
               the y world coordinate of the cursor (optional).
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 01 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgband( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;      /* This is the int variable which contains the result of
                       "Tcl_*" function calls */
  
  integer liMode;   /* This is the integer variable which contains the mode */
  integer liPGBand; /* This is the integer variable which contains the pgband
                       output flag */
  integer liPosn;   /* This is the integer variable which contains the position
                       flag */
  
  real rX;          /* This is the real variable which contains the x world
                       coordinate of the cursor */
  real rXRef;       /* This is the real variable which contains the x world
                       coordinate of the anchor */
  real rY;          /* This is the real variable which contains the y world
                       coordinate of the cursor */
  real rYRef;       /* This is the real variable which contains the y world
                       coordinate of the anchor */
  
  char psChar[2];   /* This is the 1D character array which contains the
                       character typed by the user */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC < 5 || iArgC > 7 )
  {
    pmtInterp->result = "!! Tcl_pgband: Invalid number of arguments...";
    return( TCL_ERROR );
  }


  /* Get the arguments for pgband( ) */
  
  memcpy( psChar, "\0", 2 );

  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liMode );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgband: Invalid mode...";
    return( TCL_ERROR );
  }

  iResult = Tcl_GetLongInt( pmtInterp, asArgV[2], &liPosn );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgband: Invalid position flag...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rXRef );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgband: Invalid x world coordinate (anchor)...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rYRef );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgband: Invalid y world coordinate (anchor)...";
    return( TCL_ERROR );
  }
  
  if ( iArgC >= 6 )
  {
    iResult = Tcl_GetFloat( pmtInterp, asArgV[5], &rX );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgband: Invalid x world coordinate (cursor)...";
      return( TCL_ERROR );
    }
  }
  else 
  {
    rX = rXRef;
  }
  
  if ( iArgC >= 7 )
  {
    iResult = Tcl_GetFloat( pmtInterp, asArgV[6], &rY );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgband: Invalid y world coordinate (cursor)...";
      return( TCL_ERROR );
    }
  }
  else
  {
    rY = rYRef;
  }
  
  
  /* Call pgband( ) */

#ifdef PGPLOT_C_WRAPPER
  liPGBand = (integer) cpgband( liMode, liPosn, rXRef, rYRef, &rX, &rY,
      psChar );
#else
  liPGBand = PGBAND( liMode, liPosn, rXRef, rYRef, rX, rY, psChar );
#endif  

  
  /* Return the answers and TCL_OK to the calling function */
  
  if ( liPGBand == 1 )
  {
    sprintf( pmtInterp->result, "%ld %f %f %s", liPGBand, rX, rY, psChar );
  }
  else
  {
    sprintf( pmtInterp->result, "%ld", liPGBand );
  }
  
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgbbuf

Description:
------------
This function creates a tcl command that begins saving graphical commands to a
buffer.  It must be registered with a tcl (or tk or [incr tcl]) int main( )
function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgbbuf command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgbbuf command itself).
               asArgV[0] contains "pgbbuf".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 01 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgbbuf( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgbbuf: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgbbuf( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgbbuf( );
#else
  PGBBUF( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgbeg

Description:
------------
This function creates a tcl command that begins a new plot in PGPLOT.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgbeg command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgbeg command itself).
               asArgV[0] contains "pgbeg", asArgV[1] contains the unit number
	       (obsolete) asArgV[2] contains the device, asArgV[3] contains the
	       number of plots in the X direction, and asArgV[4] contains the
	       number of plots in the Y direction.
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 Apr 15 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgbeg( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;        /* This is the int variable which contains the result of
                         "Tcl_*" function calls */
  
  integer liNumPlotX; /* This is the integer variable which contains the number
		         of plots in the X direction */
  integer liNumPlotY; /* This is the integer variable which contains the number
			 of plots in the Y direction */
  integer liPgbegin;  /* This is the integer variable which contains the pgbeg
                         flag */
  integer liUnit;     /* This is the integer variable which contains the unit
                         number (PGPLOT no longer uses it, so it is more or less
			 arbitrary) */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pgbeg: Invalid number of arguments...";
    return( TCL_ERROR );
  }


  /* Get the arguments for pgbeg( ) */

  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liUnit );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgbeg: Invalid unit number...";
    return( TCL_ERROR );
  }

  iResult = Tcl_GetLongInt( pmtInterp, asArgV[3], &liNumPlotX );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgbeg: Invalid number of plots in the x direction...";
    return( TCL_ERROR );
  }

  if ( liNumPlotX < 0 )
  {
    pmtInterp->result = "!! Tcl_pgbeg: Invalid number of plots in the x direction...";
    return( TCL_ERROR );
  }

  iResult = Tcl_GetLongInt( pmtInterp, asArgV[4], &liNumPlotY );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgbeg: Invalid number of plots in the y direction...";
    return( TCL_ERROR );
  }

  if ( liNumPlotY < 0 )
  {
    pmtInterp->result = "!! Tcl_pgbeg: Invalid number of plots in the y direction...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgbeg( ) */

#ifdef PGPLOT_C_WRAPPER
  liPgbegin = (integer) cpgbeg( liUnit, asArgV[2], liNumPlotX, liNumPlotY );
#else
  liPgbegin = PGBEG( liUnit, asArgV[2], liNumPlotX, liNumPlotY );
#endif
  
  
  /* Return the pgbeg flag and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liPgbegin );
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgbin

Description:
------------
This function creates a tcl command that plots a histogram in PGPLOT.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgbin command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgbin command itself).
               asArgV[0] contains "pgbin", asArgV[1] contains the number of
               bins, asArgV[2] contains the list of bins, asArgV[3] contains
               the list of data, and asArgV[4] contains the center flag.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgbin( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{


  /* Declare the local variables */
  
  int iBin;         /* This is the int variable which contains the bin
                       counter */
  int iNumBin2;     /* This is the int variable which contains the temporary
                       version of liNumBin */
  int iResult;      /* This is the int variable which contains the result of
                       "Tcl_*" function calls */
  
  integer liCenter; /* This is the integer variable which contains the center
                       flag */
  integer liNumBin; /* This is the integer variable which contains the number of
                       bins */
  
  real *prBin;      /* This is the pointer to the 1D real array which contains
                       the bin values */
  real *prData;     /* This is the pointer to the 1D real array which contains
                       the data values */
  
  char **asTclList; /* This is the pointer to the 2D char array which contains a
                       tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pgbin: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgbin( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNumBin );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgbin: Invalid number of bins...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumBin < 1 ) || ( liNumBin > iNumBinPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgbin: Invalid number of bins...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[2], &iNumBin2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgbin: Not enough memory...";
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumBin2 ) != liNumBin )
  {
    pmtInterp->result = "!! Tcl_pgbin: Invalid number of bins...";
    free( (char*) asTclList );
    return( TCL_ERROR );
  }
  
  ALLOC1( prBin, real, ( liNumBin - 1 ) );
  
  for ( iBin = 0; iBin <= ( liNumBin - 1 ); iBin++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iBin], &prBin[iBin] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgbin: Invalid value...";
      free( (char*) asTclList );
      DEALLOC1( prBin );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[3], &iNumBin2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgbin: Not enough memory...";
    DEALLOC1( prBin );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumBin2 ) != liNumBin )
  {
    pmtInterp->result = "!! Tcl_pgbin: Invalid number of bins...";
    free( (char*) asTclList );
    DEALLOC1( prBin );
    return( TCL_ERROR );
  }
  
  ALLOC1( prData, real, ( liNumBin - 1 ) );
  
  for ( iBin = 0; iBin <= ( liNumBin - 1 ); iBin++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iBin], &prData[iBin] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgbin: Invalid value...";
      free( (char*) asTclList );
      DEALLOC1( prBin );
      DEALLOC1( prData );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[4], &liCenter );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgbin: Invalid center flag...";
    DEALLOC1( prBin );
    DEALLOC1( prData );
    return( TCL_ERROR );
  }
  
  if ( ( liCenter != 0 ) && ( liCenter != 1 ) )
  {
    pmtInterp->result = "!! Tcl_pgbin: Invalid center flag...";
    DEALLOC1( prBin );
    DEALLOC1( prData );
    return( TCL_ERROR );
  }
  
  
  /* Call pgbin( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgbin( liNumBin, prBin, prData, liCenter );
#else
  PGBIN( liNumBin, prBin, prData, liCenter );
#endif
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prBin );
  DEALLOC1( prData );
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgbox

Description:
------------
This function creates a tcl command that draws a labelled frame around a
viewport.  It must be registered with a tcl (or tk or [incr tcl]) int main( )
function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgbox command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgbox command itself).
               asArgV[0] contains "pgbox", asArgV[1] contains the x-axis option
               string, asArgV[2] contains the x-axis tick interval, asArgV[3]
               contains the x-axis number of subintervals, asArgV[4] contains
               the y-axis option string, asArgV[5] contains the y-axis tick
               interval, and asArgV[6] contains the y-axis number of
               subintervals.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgbox( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;     /* This is the int variable which contains the result of
                      "Tcl_*" function calls */
  
  integer liNXSub; /* This is the integer variable which contains the x-axis
                      number of subintervals */
  integer liNYSub; /* This is the integer variable which contains the y-axis
                      number of subintervals */
  
  real rXTick;     /* This is the real variable which contains the x-axis tick
                      interval */
  real rYTick;     /* This is the real variable which contains the y-axis tick
                      interval */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 7 )
  {
    pmtInterp->result = "!! Tcl_pgbox: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgbox( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rXTick );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgbox: Invalid x-axis tick interval...";
    return( TCL_ERROR );
  }
  
  if ( rXTick < 0.0 )
  {
    pmtInterp->result = "!! Tcl_pgbox: Invalid x-axis tick interval...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[3], &liNXSub );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgbox: Invalid x-axis number of subintervals...";
    return( TCL_ERROR );
  }
  
  if ( liNXSub < 0 )
  {
    pmtInterp->result = "!! Tcl_pgbox: Invalid x-axis number of subintervals...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[5], &rYTick );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgbox: Invalid y-axis tick interval...";
    return( TCL_ERROR );
  }
  
  if ( rYTick < 0.0 )
  {
    pmtInterp->result = "!! Tcl_pgbox: Invalid y-axis tick interval...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[6], &liNYSub );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgbox: Invalid y-axis number of subintervals...";
    return( TCL_ERROR );
  }
  
  if ( liNYSub < 0 )
  {
    pmtInterp->result = "!! Tcl_pgbox: Invalid y-axis number of subintervals...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgbox( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgbox( asArgV[1], rXTick, liNXSub, asArgV[4], rYTick, liNYSub );
#else
  PGBOX( asArgV[1], rXTick, liNXSub, asArgV[4], rYTick, liNYSub );
#endif
 
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgcirc

Description:
------------
This function creates a tcl command that draws a circle.  It must be registered
with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgcirc command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgcirc command itself).
               asArgV[0] contains "pgcirc", asArgV[1] contains the world
               coordinate of the x-axis center, asArgV[2] contains the world
               coordinate of the y-axis center, and asArgV[3] contains the world
               coordinate radius.
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgcirc( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */

  real rRadius; /* This is the real variable which contains the world coordinate
                   radius */
  real rXCent;  /* This is the real variable which contains the world coordinate
                   of the x-axis center */
  real rYCent;  /* This is the real variable which contains the world coordinate
                   of the y-axis center */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 4 )
  {
    pmtInterp->result = "!! Tcl_pgcirc: Invalid number of arguments...";
    return( TCL_ERROR );
  }


  /* Get the arguments for pgcirc( ) */

  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rXCent );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgcirc: Invalid world coordinate x-axis center...";
    return( TCL_ERROR );
  }

  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rYCent );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgcirc: Invalid world coordinate y-axis center...";
    return( TCL_ERROR );
  }

  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rRadius );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgcirc: Invalid world coordinate radius...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgcirc( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgcirc( rXCent, rYCent, rRadius );
#else
  PGCIRC( rXCent, rYCent, rRadius );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgclos

Description:
------------
This function creates a tcl command that closes the currently selected graphics
device in PGPLOT.  It must be registered with a tcl (or tk or [incr tcl]) int
main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgclos command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgclos command itself).
               asArgV[0] contains "pgclos".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1997 May 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgclos( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgclos: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgclos( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgclos( );
#else
  PGCLOS( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgcurs

Description:
------------
This function creates a tcl command that sets and returns the cursor position.
It must be registered with a tcl (or tk or [incr tcl]) int main( ) function to
be used.  The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgcurs command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgcurs command itself).
               asArgV[0] contains "pgcurs", asArgV[1] contains the x world
               coordinate of the cursor, and asArgV[2] contains the y world
               coordinate of the cursor.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 09 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgcurs( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  integer liPGCurs; /* This is the integer variable which contains the PGPLOT
		       cursor flag */

  real rX;          /* This is the real variable which contains the x-axis
		       cursor position in world coordinates */
  real rY;          /* This is the real variable which contains the y-axis
		       cursor position in world coordinates */
  
  char psChar[2];   /* This is the pointer to the 1D int array which contains
		       the character typed by the user */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC > 3 )
  {
    pmtInterp->result = "!! Tcl_pgcurs: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgcurs( ) */
  
  memcpy( psChar, "\0", 2 );

#ifdef PGPLOT_C_WRAPPER
  liPGCurs = (integer) cpgcurs( &rX, &rY, psChar );
#else
  liPGCurs = PGCURS( rX, rY, psChar );
#endif
  
  
  /* Return rX, rY, psChar, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld %f %f %s", liPGCurs, rX, rY, psChar );
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgdraw

Description:
------------
This function creates a tcl command that draws a line.  It must be registered
with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgdraw command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgdraw command itself).
               asArgV[0] contains "pgdraw", asArgV[1] contains the x world
               coordinate of the line end point, and asArgV[2] contains the y
               world coordinate of the line end point.
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgdraw( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult; /* This is the int variable which contains the result of "Tcl_*"
                  function calls */

  real rX;     /* This is the real variable which contains the x world
                  coordinate of the line end point */
  real rY;     /* This is the real variable which contains the y world
                  coordinate of the line end point */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 3 )
  {
    pmtInterp->result = "!! Tcl_pgdraw: Invalid number of arguments...";
    return( TCL_ERROR );
  }


  /* Get the arguments for pgdraw( ) */

  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rX );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgdraw: Invalid x world coordinate...";
    return( TCL_ERROR );
  }

  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rY );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgdraw: Invalid y world coordinate...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgdraw( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgdraw( rX, rY );
#else
  PGDRAW( rX, rY );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgebuf

Description:
------------
This function creates a tcl command that ends saving graphical commands to a
buffer.  It must be registered with a tcl (or tk or [incr tcl]) int main( )
function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgebuf command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgebuf command itself).
               asArgV[0] contains "pgebuf".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 01 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgebuf( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgebuf: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgebuf( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgebuf( );
#else
  PGEBUF( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgend

Description:
------------
This function creates a tcl command that finishes a plot in PGPLOT.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgend command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgend command itself).
               asArgV[0] contains "pgend".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 Apr 17 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgend( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgend: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgend( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgend( );
#else
  PGEND( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgenv

Description:
------------
This function creates a tcl command that initializes the PGPLOT environment.  It
must be registered with a tcl (or tk or [incr tcl]) int main( ) function to be 
used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgenv command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgenv command itself).
               asArgV[0] contains "pgenv", asArgV[1] contains the x-axis lower 
               limit, asArgV[2] contains the x-axis upper limit, asArgV[3]
               contains the y-axis lower limit, asArgV[4] contains the y-axis
               upper limit, asArgV[5] contains the scale flag, and asArgV[6] 
               contains the box flag.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 Apr 17 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgenv( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;     /* This is the int variable which contains the result of
                      "Tcl_*" function calls */
  
  integer liBox;   /* This is the integer variable which contains the box
		      flag */
  integer liScale; /* This is the integer variable which contains the scale
                      flag */
  
  real rXAxisLow;  /* This is the real variable which contains the x axis lower
                      limit */
  real rXAxisHigh; /* This is the real variable which contains the x axis upper
                      limit */
  real rYAxisLow;  /* This is the real variable which contains the y axis lower
                      limit */
  real rYAxisHigh; /* This is the real variable which contains the y axis upper
                      limit */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 7 )
  {
    pmtInterp->result = "!! Tcl_pgenv: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgenv( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rXAxisLow );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgenv: Invalid x-axis lower limit...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rXAxisHigh );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgenv: Invalid x-axis upper limit...";
    return( TCL_ERROR );
  }

  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rYAxisLow );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgenv: Invalid y-axis lower limit...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rYAxisHigh );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgenv: Invalid y-axis upper limit...";
    return( TCL_ERROR );
  }
 
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[5], &liScale );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgenv: Invalid scale flag...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[6], &liBox );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgenv: Invalid box flag...";
    return( TCL_ERROR );
  }
  
  if ( ( liBox < -2 ) || ( liBox > 30 ) )
  {
    pmtInterp->result = "!! Tcl_pgenv: Invalid box flag...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgenv( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgenv( rXAxisLow, rXAxisHigh, rYAxisLow, rYAxisHigh, liScale, liBox );
#else
  PGENV( rXAxisLow, rXAxisHigh, rYAxisLow, rYAxisHigh, liScale, liBox );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgeras

Description:
------------
This function creates a tcl command that erases all graphics from the current
page or panel.  It must be registered with a tcl (or tk or [incr tcl]) int
main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgeras command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgeras command itself).
               asArgV[0] contains "pgeras".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgeras( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgeras: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgeras( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgeras( );
#else
  PGERAS( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgerrb

Description:
------------
This function creates a tcl command that plots error bars in PGPLOT.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgerrb command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgerrb command itself).
               asArgV[0] contains "pgerrb", asArgV[1] contains the PGPLOT
               direction flag, asArgV[2] contains the number of error bars,
               asArgV[3] contains the list of error values, asArgV[4] contains
               the list of x values, asArgV[5] contains the list of y values,
               and asArgV[6] contains the serif lengths in terms of the default
               length.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 09 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgerrb( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iData;         /* This is the int variable which contains the data
                        counter */
  int iNumData2;     /* This is the int variable which contains the temporary
                        version of liNumData */
  int iResult;       /* This is the int variable which contains the result of
                        "Tcl_*" function calls */
  
  integer liDir;     /* This is the integer variable which contains the PGPLOT
                        error bar direction flag */
  integer liNumData; /* This is the integer variable which contains the number
                        of error bars */
  
  real rSerif;       /* This is the real variable which contains the length of
                        the serifs as a multiple of the default length */
    
  real *prErr;       /* This is the pointer to the 1D real array which contains
                        the error bar lengths */
  real *prX;         /* This is the pointer to the 1D real array which contains
                        the x values */
  real *prY;         /* This is the pointer to the 1D real array which contains
                        the y values */
  
  char **asTclList;  /* This is the pointer to the 2D char array which contains
                        a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 7 )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgerrb( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liDir );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Invalid PGPLOT error bar direction flag...";
    return( TCL_ERROR );
  }
  
  if ( ( liDir < 1 ) || ( liDir > 4 ) )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Invalid PGPLOT error bar direction flag...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[2], &liNumData );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[3], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Not enough memory...";
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Invalid number of data points...";
    free( (char*) asTclList );
    return( TCL_ERROR );
  }
  
  ALLOC1( prX, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prX[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerrb: Invalid x value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[4], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Not enough memory...";
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  ALLOC1( prY, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prY[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerrb: Invalid y value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[5], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Not enough memory...";
    DEALLOC1( prX );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prX );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  ALLOC1( prErr, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prErr[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerrb: Invalid error value...";
      free( (char*) asTclList );
      DEALLOC1( prErr );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[6], &rSerif );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrb: Invalid serif length multiple...";
    DEALLOC1( prErr );
    DEALLOC1( prX );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  
  /* Call pgerrb( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgerrb( liDir, liNumData, prX, prY, prErr, rSerif );
#else
  PGERRB( liDir, liNumData, prX, prY, prErr, rSerif );
#endif
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prErr );
  DEALLOC1( prX );
  DEALLOC1( prY );
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgerrx

Description:
------------
This function creates a tcl command that plots x error bars in PGPLOT.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgerrx command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgerrx command itself).
               asArgV[0] contains "pgerrx", asArgV[1] contains the number of
               error bars, asArgV[2] contains the list of x values (lower),
               asArgV[3] contains the list of x values (upper), as ArgV[4]
               contains the list of y values, and asArgV[5] contains the serif
               lengths in terms of the default length.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 Apr 17 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgerrx( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iData;         /* This is the int variable which contains the data
                        counter */
  int iNumData2;     /* This is the int variable which contains the temporary
                        version of liNumData */
  int iResult;       /* This is the int variable which contains the result of
                        "Tcl_*" function calls */
  
  integer liNumData; /* This is the integer variable which contains the number
                        of error bars */
  
  real rSerif;       /* This is the real variable which contains the length of
                        the serifs as a multiple of the default length */
    
  real *prXHigh;     /* This is the pointer to the 1D real array which contains
                        the x values (upper) */
  real *prXLow;      /* This is the pointer to the 1D real array which contains
                        the x values (lower) */
  real *prY;         /* This is the pointer to the 1D real array which contains
                        the y values */
  
  char **asTclList;  /* This is the pointer to the 2D char array which contains
                        a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 6 )
  {
    pmtInterp->result = "!! Tcl_pgerrx: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgerrx( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNumData );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrx: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgerrx: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[2], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrx: Not enough memory...";
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerrx: Invalid number of data points...";
    free( (char*) asTclList );
    return( TCL_ERROR );
  }
  
  ALLOC1( prXLow, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prXLow[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerrx: Invalid x value (lower)...";
      free( (char*) asTclList );
      DEALLOC1( prXLow );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[3], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrx: Not enough memory...";
    DEALLOC1( prXLow );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerrx: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prXLow );
    return( TCL_ERROR );
  }
  
  ALLOC1( prXHigh, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prXHigh[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerrx: Invalid x value (upper)...";
      free( (char*) asTclList );
      DEALLOC1( prXLow );
      DEALLOC1( prXHigh );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[4], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrx: Not enough memory...";
    DEALLOC1( prXLow );
    DEALLOC1( prXHigh );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerrx: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prXLow );
    DEALLOC1( prXHigh );
    return( TCL_ERROR );
  }
  
  ALLOC1( prY, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prY[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerrx: Invalid y value...";
      free( (char*) asTclList );
      DEALLOC1( prXLow );
      DEALLOC1( prXHigh );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[5], &rSerif );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrx: Invalid serif length multiple...";
    DEALLOC1( prXLow );
    DEALLOC1( prXHigh );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  
  /* Call pgerrx( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgerrx( liNumData, prXLow, prXHigh, prY, rSerif );
#else
  PGERRX( liNumData, prXLow, prXHigh, prY, rSerif );
#endif
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prXLow );
  DEALLOC1( prXHigh );
  DEALLOC1( prY );
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgerrx2

Description:
------------
This function creates a tcl command that plots x error bars in PGPLOT.  It is
different from the original version of this function, Tcl_pgerrx( ), because it
is not necessary to enter the upper and lower values of the x error bars, just
the x values and their errors.  It must be registered with a tcl (or tk or
[incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgerrx2 command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgerrx2 command itself).
               asArgV[0] contains "pgerrx2", asArgV[1] contains the number of
               data points, asArgV[2] contains the error bar multiplier, 
               asArgV[3] contains the x error bars, asArgV[4] contains the x 
               values, asArgV[5] contains the y values, and asArgV[6] contains
               the serif lengths in terms of the default length.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 May 07 - Nicholas Elias, USNO/AD5
              Function created.
1994 Jun 03 - Nicholas Elias, USNO/AD5
              Argument list modified.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgerrx2( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iData;         /* This is the int variable which contains the data
                        counter */
  int iNumData2;     /* This is the int variable which contains the temporary
                        version of liNumData */
  int iResult;       /* This is the int variable which contains the result of
                        "Tcl_*" function calls */
  
  integer liNumData; /* This is the integer variable which contains the number
                        of data points */
  
  real rMultErr;     /* This is the real variable which contains the error bar
                        multiplier */
  real rSerif;       /* This is the real variable which contains the length of
                        the serifs as a multiple of the default length */
                         
  real *prX;         /* This is the pointer to the 1D real array which contains
                        the x values */
  real *prXErr;      /* This is the pointer to the 1D real array which contains
                        the x error bars */
  real *prY;         /* This is the pointer to the 1D real array which contains
                        the y values */
  
  char **asTclList;  /* This is the pointer to the 2D char array which contains
                        a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 7 )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgerrx2( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNumData );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rMultErr );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Invalid error bar multiplier...";
    return( TCL_ERROR );
  }
  
  if ( rMultErr <= 0.0 )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Invalid error bar multiplier...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[3], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Not enough memory...";
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Invalid number of data points...";
    free( (char*) asTclList );
    return( TCL_ERROR );
  }
  
  ALLOC1( prXErr, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prXErr[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerrx2: Invalid x error bar...";
      free( (char*) asTclList );
      DEALLOC1( prXErr );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[4], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Not enough memory...";
    DEALLOC1( prXErr );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prXErr );
    return( TCL_ERROR );
  }
  
  ALLOC1( prX, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prX[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerrx2: Invalid x value...";
      free( (char*) asTclList );
      DEALLOC1( prXErr );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[5], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Not enough memory...";
    DEALLOC1( prXErr );
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prXErr );
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  ALLOC1( prY, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prY[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerrx2: Invalid y value...";
      free( (char*) asTclList );
      DEALLOC1( prXErr );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[6], &rSerif );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerrx2: Invalid serif length multiple...";
    DEALLOC1( prXErr );
    DEALLOC1( prX );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  
  /* Call pgerrx2( ) */
  
  pgerrx2( &liNumData, &rMultErr, prXErr, prX, prY, &rSerif );
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prXErr );
  DEALLOC1( prX );
  DEALLOC1( prY );
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgerry

Description:
------------
This function creates a tcl command that plots y error bars in PGPLOT.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgerry command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgerry command itself).
               asArgV[0] contains "pgerry", asArgV[1] contains the number of
               error bars, asArgV[2] contains the list of x values, asArgV[3] 
               contains the list of y values (lower), as ArgV[4] contains the 
               list of y values (upper) , and asArgV[5] contains the serif
               lengths in terms of the default length.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 Apr 17 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgerry( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{


  /* Declare the local variables */
  
  int iData;         /* This is the int variable which contains the data
                        counter */
  int iNumData2;     /* This is the int variable which contains the temporary
                        version of liNumData */
  int iResult;       /* This is the int variable which contains the result of
                        "Tcl_*" function calls */
  
  integer liNumData; /* This is the integer variable which contains the number
                        of error bars */
  
  real rSerif;       /* This is the real variable which contains the length of
                        the serifs as a multiple of the default length */
                         
  real *prX;         /* This is the pointer to the 1D real array which contains
                        the x values */
  real *prYLow;      /* This is the pointer to the 1D real array which contains
                        the y values (lower) */
  real *prYHigh;     /* This is the pointer to the 1D real array which contains
                        the y values (upper) */
  
  char **asTclList;  /* This is the pointer to the 2D char array which contains
                        a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 6 )
  {
    pmtInterp->result = "!! Tcl_pgerry: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgerry( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNumData );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerry: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgerry: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[2], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerry: Not enough memory...";
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerry: Invalid number of data points...";
    free( (char*) asTclList );
    return( TCL_ERROR );
  }
  
  ALLOC1( prX, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prX[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerry: Invalid x value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[3], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerry: Not enough memory...";
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerry: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  ALLOC1( prYLow, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prYLow[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerry: Invalid y value (lower)...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      DEALLOC1( prYLow );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[4], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerry: Not enough memory...";
    DEALLOC1( prX );
    DEALLOC1( prYLow );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerry: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prX );
    DEALLOC1( prYLow );
    return( TCL_ERROR );
  }
  
  ALLOC1( prYHigh, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prYHigh[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerry: Invalid y value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      DEALLOC1( prYLow );
      DEALLOC1( prYHigh );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[5], &rSerif );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerry: Invalid serif length multiple...";
    DEALLOC1( prX );
    DEALLOC1( prYLow );
    DEALLOC1( prYHigh );
    return( TCL_ERROR );
  }
  
  
  /* Call pgerry( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgerry( liNumData, prX, prYLow, prYHigh, rSerif );
#else
  PGERRY( liNumData, prX, prYLow, prYHigh, rSerif );
#endif
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prX );
  DEALLOC1( prYLow );
  DEALLOC1( prYHigh );
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgerry2

Description:
------------
This function creates a tcl command that plots y error bars in PGPLOT.  It is
different from the original version of this function, Tcl_pgerry( ), because it
is not necessary to enter the upper and lower values of the y error bars, just
the y values and their errors.  It must be registered with a tcl (or tk or
[incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgerry2 command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgerry2 command itself).
               asArgV[0] contains "pgerry2", asArgV[1] contains the number of
               data points, asArgV[2] contains the error bar multiplier, 
               asArgV[3] contains the y error bars, asArgV[4] contains the x 
               values, asArgV[5] contains the y values, and asArgV[6] contains
               the serif lengths in terms of the default length.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 May 07 - Nicholas Elias, USNO/AD5
              Function created.
1994 Jun 03 - Nicholas Elias, USNO/AD5
              Argument list modified.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgerry2( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iData;         /* This is the int variable which contains the data
                        counter */
  int iNumData2;     /* This is the int variable which contains the temporary
                        version of liNumData */
  int iResult;       /* This is the int variable which contains the result of
                        "Tcl_*" function calls */
  
  integer liNumData; /* This is the integer variable which contains the number
                        of data points */
  
  real rMultErr;     /* This is the real variable which contains the error bar
                        multiplier */
  real rSerif;       /* This is the real variable which contains the length of
                        the serifs as a multiple of the default length */
                         
  real *prX;         /* This is the pointer to the 1D real array which contains
                        the x values */
  real *prY;         /* This is the pointer to the 1D real array which contains
                        the y values */
  real *prYErr;      /* This is the pointer to the 1D real array which contains
                        the y error bars */
  
  char **asTclList;  /* This is the pointer to the 2D char array which contains
                        a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 7 )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgerry2( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNumData );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rMultErr );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Invalid error bar multiplier...";
    return( TCL_ERROR );
  }
  
  if ( rMultErr <= 0.0 )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Invalid error bar multiplier...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[3], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Not enough memory...";
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Invalid number of data points...";
    free( (char*) asTclList );
    return( TCL_ERROR );
  }
  
  ALLOC1( prYErr, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prYErr[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerry2: Invalid y error bar...";
      free( (char*) asTclList );
      DEALLOC1( prYErr );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[4], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Not enough memory...";
    DEALLOC1( prYErr );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prYErr );
    return( TCL_ERROR );
  }
  
  ALLOC1( prX, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prX[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerry2: Invalid x value...";
      free( (char*) asTclList );
      DEALLOC1( prYErr );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[5], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Not enough memory...";
    DEALLOC1( prYErr );
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prYErr );
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  ALLOC1( prY, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prY[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgerry2: Invalid y value...";
      free( (char*) asTclList );
      DEALLOC1( prYErr );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[6], &rSerif );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgerry2: Invalid serif length multiple...";
    DEALLOC1( prYErr );
    DEALLOC1( prX );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  
  /* Call pgerry2( ) */
  
  pgerry2( &liNumData, &rMultErr, prYErr, prX, prY, &rSerif );
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prYErr );
  DEALLOC1( prX );
  DEALLOC1( prY );
  
  
  /* Return "" and  TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgetxt

Description:
------------
This function creates a tcl command that erases interactive text from the
graphics display.  It must be registered with a tcl (or tk or [incr tcl]) int
main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgetxt command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgetxt command itself).
               asArgV[0] contains "pgetxt".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgetxt( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgetxt: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgetxt( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgetxt( );
#else
  PGETXT( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgfunt

Description:
------------
This function creates a tcl command that draws a curve defined by the equations
x = fx(t) and y = fy(t), where fx and fy are tcl commands that take a single
argument t.  It must be registered with a tcl (or tk or [incr tcl]) int main( )
function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgfunt command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgfunt command itself).
               asArgV[0] contains "pgfunt", asArgV[1] contains the name of the x
               tcl command, asArgV[2] contains the name of the y tcl command,
               asArgV[3] contains the number of data points, asArgV[4] contains
               the minimum t value, asArgV[5] contains the maximum t value, and
               asArgV[6] contains the pgenv flag.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 05 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgfunt( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{

  /* Declare the local variables */
  
  char *psTclCommand; /* This is the pointer to the 1D char array which contains
                         a tcl command */
  char *psT;          /* This is the pointer to the 1D char array which contains
                         a t value */
  
  int iData;          /* This is the int variable which contains the data
                         counter */
  int iResult;        /* This is the int variable which contains the result of
                         "Tcl_*" function calls */
  
  integer liNumData;  /* This is the integer variable which contains the number
                         of data points */
  integer liFlag;     /* This is the integer variable which contains the PGPLOT
                         pgenv flag.  It must be 0 or 1 */
  integer liZero = 0; /* This is the integer variable which contains the number
                         0 */
  
  real rDT;           /* This is the real variable which contains the t
                         increment */
  real rT;            /* This is the real variable which contains a t value */
  real rTMin;         /* This is the real variable which contains the minimum t
                         value */
  real rTMax;         /* This is the real variable which contains the maximum t
                         value */
  real rXMin;         /* This is the real variable which contains the minimum x
                         value */
  real rXMax;         /* This is the real variable which contains the maximum x
                         value */
  real rYMin;         /* This is the real variable which contains the minimum y
                         value */
  real rYMax;         /* This is the real variable which contains the maximum x
                         value */
  
  real *prX;          /* This is the pointer to the 1D real array which contains
                         the x values */
  real *prY;          /* This is the pointer to the 1D real array which contains
                         the y values */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 7 )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Set the tcl precision */
  
  ALLOC1( psTclCommand, char, 20 );
  
  strcpy( psTclCommand, "set tcl_precision 17" );
  
  iResult = Tcl_Eval( pmtInterp, psTclCommand );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Problem setting tcl precision...";
    return( TCL_ERROR );
  }
  
  DEALLOC1( psTclCommand );
  
  
  /* Get the arguments for pgline( ) */
  
  ALLOC1( psTclCommand, char, ( 14 + strlen( asArgV[1] ) ) );
  
  strcpy( psTclCommand, "info commands " );
  strcat( psTclCommand, asArgV[1] );
  
  iResult = Tcl_Eval( pmtInterp, psTclCommand );
  
  DEALLOC1( psTclCommand );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Invalid tcl command...";
    return( TCL_ERROR );
  }
  
  if ( strcmp( pmtInterp->result, asArgV[1] ) )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Invalid tcl command...";
    return( TCL_ERROR );
  }
  
  ALLOC1( psTclCommand, char, ( 14 + strlen( asArgV[2] ) ) );
  
  strcpy( psTclCommand, "info commands " );
  strcat( psTclCommand, asArgV[2] );
  
  iResult = Tcl_Eval( pmtInterp, psTclCommand );
  
  DEALLOC1( psTclCommand );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Invalid tcl command...";
    return( TCL_ERROR );
  }
  
  if ( strcmp( pmtInterp->result, asArgV[2] ) )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Invalid tcl command...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[3], &liNumData );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rTMin );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Invalid minimum t value...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[5], &rTMax );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Invalid maximum t value...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[6], &liFlag );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Invalid PGPLOT pgenv flag...";
    return( TCL_ERROR );
  }
  
  if ( ( liFlag != 0 ) && ( liFlag != 1 ) )
  {
    pmtInterp->result = "!! Tcl_pgfunt: Invalid PGPLOT pgenv flag...";
    return( TCL_ERROR );
  }
  
  
  /* Calculate the points for pgline( ) */
  
  ALLOC1( psTclCommand, char, ( strlen( asArgV[1] ) + 500 ) );
  ALLOC1( psT, char, 100 );
  
  ALLOC1( prX, real, ( liNumData - 1 ) );
  ALLOC1( prY, real, ( liNumData - 1 ) );
  
  rDT = ( rTMax - rTMin ) / ( (float) ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {  
    rT = rTMin + ( (float) iData * rDT );
    sprintf( psT, " %.17f", rT );
    strcpy( psTclCommand, asArgV[1] );
    strcat( psTclCommand, psT );
    iResult = Tcl_Eval( pmtInterp, psTclCommand );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgfunt: Tcl command problem...";
      DEALLOC1( psTclCommand );
      DEALLOC1( psT );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
    prX[iData] = (real) atof( (const char*) pmtInterp->result );
    strcpy( psTclCommand, asArgV[2] );
    strcat( psTclCommand, psT );
    iResult = Tcl_Eval( pmtInterp, psTclCommand );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgfunt: Tcl command problem...";
      DEALLOC1( psTclCommand );
      DEALLOC1( psT );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
    prY[iData] = (real) atof( (const char*) pmtInterp->result );
  }
  
  DEALLOC1( psTclCommand );
  DEALLOC1( psT );
  
  
  /* Call pgline( ) */
  
  if ( liFlag == 0 )
  {
    MINDATA( liNumData, prX, rXMin );
    MAXDATA( liNumData, prX, rXMax );
    MINDATA( liNumData, prY, rYMin );
    MAXDATA( liNumData, prY, rYMax );
#ifdef PGPLOT_C_WRAPPER
    cpgenv( rXMin, rXMax, rYMin, rYMax, liZero, liZero );
#else
    PGENV( rXMin, rXMax, rYMin, rYMax, liZero, liZero );
#endif
  }

#ifdef PGPLOT_C_WRAPPER
  cpgline( liNumData, prX, prY );
#else
  PGLINE( liNumData, prX, prY );
#endif
  
  DEALLOC1( prX );
  DEALLOC1( prY );
  
  
  /* Return "" and TCL_OK to the calling function */
  
  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgfunx

Description:
------------
This function creates a tcl command that draws a curve defined by the equation
y = f(x), where f is a tcl command that takes a single argument x.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgfunx command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgfunx command itself).
               asArgV[0] contains "pgfunx", asArgV[1] contains the name of the
               tcl command, asArgV[2] contains the number of data points,
               asArgV[3] contains the minimum x value, asArgV[4] contains the
               maximum x value, and asArgV[5] contains the pgenv flag.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 05 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgfunx( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{

  /* Declare the local variables */
  
  char *psTclCommand; /* This is the pointer to the 1D char array which contains
                         a tcl command */
  char *psX;          /* This is the pointer to the 1D char array which contains
                         an x value */
  
  int iData;          /* This is the int variable which contains the data
                         counter */
  int iResult;        /* This is the int variable which contains the result of
                         "Tcl_*" function calls */
  
  integer liNumData;  /* This is the integer variable which contains the number
                         of data points */
  integer liFlag;     /* This is the integer variable which contains the PGPLOT
                         pgenv flag.  It must be 0 or 1 */
  integer liZero = 0; /* This is the integer variable which contains the number
                         0 */
  
  real rDX;           /* This is the real variable which contains the x
                         increment */
  real rXMin;         /* This is the real variable which contains the minimum x
                         value */
  real rXMax;         /* This is the real variable which contains the maximum x
                         value */
  real rYMin;         /* This is the real variable which contains the minimum y
                         value */
  real rYMax;         /* This is the real variable which contains the maximum x
                         value */
  
  real *prX;          /* This is the pointer to the 1D real array which contains
                         the x values */
  real *prY;          /* This is the pointer to the 1D real array which contains
                         the y values */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 6 )
  {
    pmtInterp->result = "!! Tcl_pgfunx: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Set the tcl precision */
  
  ALLOC1( psTclCommand, char, 20 );
  
  strcpy( psTclCommand, "set tcl_precision 17" );
  
  iResult = Tcl_Eval( pmtInterp, psTclCommand );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunx: Problem setting tcl precision...";
    return( TCL_ERROR );
  }
  
  DEALLOC1( psTclCommand );
  
  
  /* Get the arguments for pgline( ) */
  
  ALLOC1( psTclCommand, char, ( 14 + strlen( asArgV[1] ) ) );
  
  strcpy( psTclCommand, "info commands " );
  strcat( psTclCommand, asArgV[1] );
  
  iResult = Tcl_Eval( pmtInterp, psTclCommand );
  
  DEALLOC1( psTclCommand );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunx: Invalid tcl command...";
    return( TCL_ERROR );
  }
  
  if ( strcmp( pmtInterp->result, asArgV[1] ) )
  {
    pmtInterp->result = "!! Tcl_pgfunx: Invalid tcl command...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[2], &liNumData );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunx: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgfunx: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rXMin );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunx: Invalid minimum x value...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rXMax );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunx: Invalid maximum x value...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[5], &liFlag );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfunx: Invalid PGPLOT pgenv flag...";
    return( TCL_ERROR );
  }
  
  if ( ( liFlag != 0 ) && ( liFlag != 1 ) )
  {
    pmtInterp->result = "!! Tcl_pgfunx: Invalid PGPLOT pgenv flag...";
    return( TCL_ERROR );
  }
  
  
  /* Calculate the points for pgline( ) */
  
  ALLOC1( psTclCommand, char, ( strlen( asArgV[1] ) + 100 ) );
  ALLOC1( psX, char, 100 );
  
  ALLOC1( prX, real, ( liNumData - 1 ) );
  ALLOC1( prY, real, ( liNumData - 1 ) );
  
  rDX = ( rXMax - rXMin ) / ( (float) ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {  
    prX[iData] = rXMin + ( (float) iData * rDX );
    sprintf( psX, " %.17f", prX[iData] );
    strcpy( psTclCommand, asArgV[1] );
    strcat( psTclCommand, psX );
    iResult = Tcl_Eval( pmtInterp, psTclCommand );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgfunx: Tcl command problem...";
      DEALLOC1( psTclCommand );
      DEALLOC1( psX );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
    prY[iData] = (real) atof( (const char*) pmtInterp->result );
  }
  
  DEALLOC1( psTclCommand );
  DEALLOC1( psX );
  
  
  /* Call pgline( ) */
  
  if ( liFlag == 0 )
  {
    MINDATA( liNumData, prY, rYMin );
    MAXDATA( liNumData, prY, rYMax );
#ifdef PGPLOT_C_WRAPPER
    cpgenv( rXMin, rXMax, rYMin, rYMax, liZero, liZero );
#else
    PGENV( rXMin, rXMax, rYMin, rYMax, liZero, liZero );
#endif
  }

#ifdef PGPLOT_C_WRAPPER
  cpgline( liNumData, prX, prY );
#else
  PGLINE( liNumData, prX, prY );
#endif
  
  DEALLOC1( prX );
  DEALLOC1( prY );
  
  
  /* Return "" and TCL_OK to the calling function */
  
  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgfuny

Description:
------------
This function creates a tcl command that draws a curve defined by the equation
x = f(y), where f is a tcl command that takes a single argument y.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgfuny command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgfuny command itself).
               asArgV[0] contains "pgfuny", asArgV[1] contains the name of the
               tcl command, asArgV[2] contains the number of data points,
               asArgV[3] contains the minimum y value, asArgV[4] contains the
               maximum y value, and asArgV[5] contains the pgenv flag.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 05 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgfuny( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{

  /* Declare the local variables */
  
  char *psTclCommand; /* This is the pointer to the 1D char array which contains
                         a tcl command */
  char *psY;          /* This is the pointer to the 1D char array which contains
                         a y value */
  
  int iData;          /* This is the int variable which contains the data
                         counter */
  int iResult;        /* This is the int variable which contains the result of
                         "Tcl_*" function calls */
  
  integer liNumData;  /* This is the integer variable which contains the number
                         of data points */
  integer liFlag;     /* This is the integer variable which contains the PGPLOT
                         pgenv flag.  It must be 0 or 1 */
  integer liZero = 0; /* This is the integer variable which contains the number
                         0 */
  
  real rDY;           /* This is the real variable which contains the y
                         increment */
  real rXMin;         /* This is the real variable which contains the minimum x
                         value */
  real rXMax;         /* This is the real variable which contains the maximum x
                         value */
  real rYMin;         /* This is the real variable which contains the minimum y
                         value */
  real rYMax;         /* This is the real variable which contains the maximum x
                         value */
  
  real *prX;          /* This is the pointer to the 1D real array which contains
                         the x values */
  real *prY;          /* This is the pointer to the 1D real array which contains
                         the y values */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 6 )
  {
    pmtInterp->result = "!! Tcl_pgfuny: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Set the tcl precision */
  
  ALLOC1( psTclCommand, char, 20 );
  
  strcpy( psTclCommand, "set tcl_precision 17" );
  
  iResult = Tcl_Eval( pmtInterp, psTclCommand );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfuny: Problem setting tcl precision...";
    return( TCL_ERROR );
  }
  
  DEALLOC1( psTclCommand );
  
  
  /* Get the arguments for pgline( ) */
  
  ALLOC1( psTclCommand, char, ( 14 + strlen( asArgV[1] ) ) );
  
  strcpy( psTclCommand, "info commands " );
  strcat( psTclCommand, asArgV[1] );
  
  iResult = Tcl_Eval( pmtInterp, psTclCommand );
  
  DEALLOC1( psTclCommand );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfuny: Invalid tcl command...";
    return( TCL_ERROR );
  }
  
  if ( strcmp( pmtInterp->result, asArgV[1] ) )
  {
    pmtInterp->result = "!! Tcl_pgfuny: Invalid tcl command...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[2], &liNumData );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfuny: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgfuny: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rYMin );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfuny: Invalid minimum y value...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rYMax );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfuny: Invalid maximum y value...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[5], &liFlag );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgfuny: Invalid PGPLOT pgenv flag...";
    return( TCL_ERROR );
  }
  
  if ( ( liFlag != 0 ) && ( liFlag != 1 ) )
  {
    pmtInterp->result = "!! Tcl_pgfuny: Invalid PGPLOT pgenv flag...";
    return( TCL_ERROR );
  }
  
  
  /* Calculate the points for pgline( ) */
  
  ALLOC1( psTclCommand, char, ( strlen( asArgV[1] ) + 100 ) );
  ALLOC1( psY, char, 100 );
  
  ALLOC1( prX, real, ( liNumData - 1 ) );
  ALLOC1( prY, real, ( liNumData - 1 ) );
  
  rDY = ( rYMax - rYMin ) / ( (float) ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {  
    prY[iData] = rYMin + ( (float) iData * rDY );
    sprintf( psY, " %.17f", prY[iData] );
    strcpy( psTclCommand, asArgV[1] );
    strcat( psTclCommand, psY );
    iResult = Tcl_Eval( pmtInterp, psTclCommand );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgfuny: Tcl command problem...";
      DEALLOC1( psTclCommand );
      DEALLOC1( psY );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
    prX[iData] = (real) atof( (const char*) pmtInterp->result );
  }
  
  DEALLOC1( psTclCommand );
  DEALLOC1( psY );
  
  
  /* Call pgline( ) */
  
  if ( liFlag == 0 )
  {
    MINDATA( liNumData, prX, rXMin );
    MAXDATA( liNumData, prX, rXMax );
#ifdef PGPLOT_C_WRAPPER
    cpgenv( rXMin, rXMax, rYMin, rYMax, liZero, liZero );
#else
    PGENV( rXMin, rXMax, rYMin, rYMax, liZero, liZero );
#endif
  }

#ifdef PGPLOT_C_WRAPPER
  cpgline( liNumData, prX, prY );
#else
  PGLINE( liNumData, prX, prY );
#endif
  
  DEALLOC1( prX );
  DEALLOC1( prY );
  
  
  /* Return "" and TCL_OK to the calling function */
  
  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pghist

Description:
------------
This function creates a tcl command that plots a histogram in PGPLOT.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pghist command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pghist command itself).
               asArgV[0] contains "pghist", asArgV[1] contains the number of
               points, asArgV[2] contains the list of values, asArgV[3] contains
               the minimum value, asArgV[4] contains the maximum value,
               asArgV[5] contains the number of bins, and asArgV[6] contains the
               bin flag.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 May 25 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pghist( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{


  /* Declare the local variables */
  
  int iData;         /* This is the int variable which contains the data
                        counter */
  int iNumData2;     /* This is the int variable which contains the temporary
                        version of liNumData */
  int iResult;       /* This is the int variable which contains the result of
                        "Tcl_*" function calls */
  
  integer liFlag;    /* This is the integer variable which contains the bin
                        flag */
  integer liNumBin;  /* This is the integer variable which contains the number
                        of bins */
  integer liNumData; /* This is the integer variable which contains the number
                        of data points */
  
  real rMax;         /* This is the real variable which contains the maximum
                        value */
  real rMin;         /* This is the real variable which contains the minimum
                        value */
  
  real *prData;      /* This is the pointer to the 1D real array which contains
                        the x values */
  
  char **asTclList;  /* This is the pointer to the 2D char array which contains
                        a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 7 )
  {
    pmtInterp->result = "!! Tcl_pghist: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pghist( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNumData );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pghist: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pghist: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[2], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pghist: Not enough memory...";
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pghist: Invalid number of data points...";
    free( (char*) asTclList );
    return( TCL_ERROR );
  }
  
  ALLOC1( prData, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prData[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pghist: Invalid value...";
      free( (char*) asTclList );
      DEALLOC1( prData );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rMin );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pghist: Invalid minimum value...";
    DEALLOC1( prData );
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rMax );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pghist: Invalid maximum value...";
    DEALLOC1( prData );
    return( TCL_ERROR );
  }
  
  if ( rMin >= rMax )
  {
    pmtInterp->result = "!! Tcl_pghist: Invalid minimum/maximum value...";
    DEALLOC1( prData );
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[5], &liNumBin );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pghist: Invalid number of bins...";
    DEALLOC1( prData );
    return( TCL_ERROR );
  }
  
  if ( liNumBin < 1 )
  {
    pmtInterp->result = "!! Tcl_pghist: Invalid number of bins...";
    DEALLOC1( prData );
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[6], &liFlag );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pghist: Invalid bin flag...";
    DEALLOC1( prData );
    return( TCL_ERROR );
  }
  
  if ( liFlag < 0 || liFlag > 5 )
  {
    pmtInterp->result = "!! Tcl_pghist: Invalid bin flag...";
    DEALLOC1( prData );
    return( TCL_ERROR );
  }
  
  
  /* Call pghist( ) */

#ifdef PGPLOT_C_WRAPPER
  cpghist( liNumData, prData, rMin, rMax, liNumBin, liFlag );
#else
  PGHIST( liNumData, prData, rMin, rMax, liNumBin, liFlag );
#endif
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prData );
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgiden

Description:
------------
This function creates a tcl command that writes identification information at
the bottom of each PGPLOT plot.  It must be registered with a tcl (or tk or
[incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgiden command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgiden command itself).
               asArgV[0] contains "pgiden".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 12 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgiden( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgiden: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgiden( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgiden( );
#else
  PGIDEN( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pglab

Description:
------------
This function creates a tcl command that prints labels in PGPLOT.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pglab command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pglab command itself).
               asArgV[0] contains "pglab", asArgV[1] contains the x-axis label,
               asArgV[2] contains the y-axis label, and asArgV[3] contains the
               title.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 Apr 17 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pglab( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 4 )
  {
    pmtInterp->result = "!! Tcl_pglab: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pglab( ) */

#ifdef PGPLOT_C_WRAPPER
  cpglab( asArgV[1], asArgV[2], asArgV[3] );
#else
  PGLAB( asArgV[1], asArgV[2], asArgV[3] );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pglcur

Description:
------------
This function creates a tcl command that allows the user to create a "polyline"
using the cursor.  It must be registered with a tcl (or tk or [incr tcl]) int
main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pglcur command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pglcur command itself).
               asArgV[0] contains "pglcur", asArgV[1] contains the maximum
               number of points to be entered, asArgV[2] contains the number of
               input points, asArgV[3] contains the list of x world coordinates,
               and asArgV[4] contains the list of y world coordinates.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pglcur( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iNPt2;                 /* This is the int variable which contains a
				temporary version of the number of points */
  int iPt;                   /* This is the int variable which contains the
				point counter */
  int iResult;               /* This is the int variable which contains the
				result of "Tcl_*" function calls */
  
  integer liMaxPt;           /* This is the integer variable which contains the
				maximum number of points */
  integer liNPt;             /* This is the integer variable which contains the
				number of points */

  char psTemp[100];          /* This is the pointer to the 1D char array which
				contains a temporary string */

  real *prX;                 /* This is the pointer to the 1D double array which
				contains the x world coordinates */
  real *prY;                 /* This is the pointer to the 1D double array which
				contains the y world coordinates */

  Tcl_Interp *pmtInterpTemp; /* This is the pointer to the Tcl_Interp variable
			        which contains a temporary tcl interpreter */

  char **asTclList;          /* This is the pointer to the 2D char array which
				contains a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 && iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pglcur: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pglcur( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liMaxPt );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pglcur: Invalid maximum number of points...";
    return( TCL_ERROR );
  }
  
  if ( liMaxPt < 1 || liMaxPt > NUM_DATA_PGPLOT )
  {
    pmtInterp->result = "!! Tcl_pglcur: Invalid maximum number of points...";
    return( TCL_ERROR );
  }
  
  if ( iArgC > 2 )
  {
  
    iResult = Tcl_GetLongInt( pmtInterp, asArgV[2], &liNPt );
  
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pglcur: Invalid number of points...";
      return( TCL_ERROR );
    }
  
    if ( liNPt < 1 || liNPt > liMaxPt )
    {
      pmtInterp->result = "!! Tcl_pglcur: Invalid number of points...";
      return( TCL_ERROR );
    }
    
    iResult = Tcl_SplitList( pmtInterp, asArgV[3], &iNPt2, &asTclList );
    
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pglcur: Invalid list of x world coordinates...";
      free( (char*) asTclList );
      return( TCL_ERROR );
    }
    
    if ( (integer) iNPt2 != liNPt )
    {
      pmtInterp->result = "!! Tcl_pglcur: Invalid list of x world coordinates...";
      free( (char*) asTclList );
      return( TCL_ERROR );
    }
    
    ALLOC1( prX, real, ( liMaxPt - 1 ) );
    
    for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
    {
      iResult = Tcl_GetFloat( pmtInterp, asTclList[iPt], &prX[iPt] );
      if ( iResult == TCL_ERROR )
      {
        pmtInterp->result = "!! Tcl_pglcur: Invalid x world coordinate...";
        free( (char*) asTclList );
        DEALLOC1( prX );
        return( TCL_ERROR );
      }
    }
    
    free( (char*) asTclList );
    
    iResult = Tcl_SplitList( pmtInterp, asArgV[4], &iNPt2, &asTclList );
    
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pglcur: Invalid list of y world coordinates...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
    
    if ( (integer) iNPt2 != liNPt )
    {
      pmtInterp->result = "!! Tcl_pglcur: Invalid list of y world coordinates...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
    
    ALLOC1( prY, real, ( liMaxPt - 1 ) );
    
    for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
    {
      iResult = Tcl_GetFloat( pmtInterp, asTclList[iPt], &prY[iPt] );
      if ( iResult == TCL_ERROR )
      {
        pmtInterp->result = "!! Tcl_pglcur: Invalid y world coordinate...";
        free( (char*) asTclList );
        DEALLOC1( prX );
        DEALLOC1( prY );
        return( TCL_ERROR );
      }
    }
  
  }
  else
  {
  
    liNPt = 0;
    
    ALLOC1( prX, real, ( liMaxPt - 1 ) );
    ALLOC1( prY, real, ( liMaxPt - 1 ) );
  
  }
  
  
  /* Call pglcur( ) */

#ifdef PGPLOT_C_WRAPPER
  cpglcur( liMaxPt, (int*) &liNPt, prX, prY );
#else
  PGLCUR( liMaxPt, liNPt, prX, prY );
#endif
    
  
  /* Return liNPt, prX, prY, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liNPt );
  
  pmtInterpTemp = Tcl_CreateInterp( );
  
  for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
  {
    sprintf( psTemp, "%f", prX[iPt] );
    Tcl_AppendElement( pmtInterpTemp, psTemp );
  }
 
  Tcl_AppendElement( pmtInterp, pmtInterpTemp->result );
  Tcl_DeleteInterp( pmtInterpTemp );
  
  DEALLOC1( prX );
  
  pmtInterpTemp = Tcl_CreateInterp( );
  
  for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
  {
    sprintf( psTemp, "%f", prY[iPt] );
    Tcl_AppendElement( pmtInterpTemp, psTemp );
  }
  
  Tcl_AppendElement( pmtInterp, pmtInterpTemp->result );
  Tcl_DeleteInterp( pmtInterpTemp );
  
  DEALLOC1( prY );
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgldev

Description:
------------
This function creates a tcl command that returns a list of all devices types
known to PGPLOT.  It must be registered with a tcl (or tk or [incr tcl]) int
main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgldev command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgldev command itself).
               asArgV[0] contains "pgldev".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgldev( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgldev: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgldev( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgldev( );
#else
  PGLDEV( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pglen

Description:
------------
This function creates a tcl command calculates the length of a string in a
variety of units.  It must be registered with a tcl (or tk or [incr tcl]) int
main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pglen command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pglen command itself).
               asArgV[0] contains "pglen", asArgV[1] contains the PGPLOT units
               flag, and asArgV[2] contains the string.
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pglen( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;    /* This is the int variable which contains the result of
                    "Tcl_*" function calls */

  integer liUnit; /* This is the integer variable which contains the PGPLOT
                     units flag */

  real rXL;       /* This is the real variable which contains the x length */
  real rYL;       /* This is the real variable which contains the y length */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 3 )
  {
    pmtInterp->result = "!! Tcl_pglen: Invalid number of arguments...";
    return( TCL_ERROR );
  }


  /* Get the arguments for pglen( ) */

  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liUnit );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pglen: Invalid PGPLOT units flag...";
    return( TCL_ERROR );
  }
  
  if ( liUnit < 0 || liUnit > 5 )
  {
    pmtInterp->result = "!! Tcl_pglen: Invalid PGPLOT units flag...";
    return( TCL_ERROR );
  }
  
  
  /* Call pglen( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpglen( liUnit, asArgV[2], &rXL, &rYL );
#else
  PGLEN( liUnit, asArgV[2], rXL, rYL );
#endif
  
  
  /* Return rXL, rYL, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%f %f", rXL, rYL );
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgline

Description:
------------
This function creates a tcl command that plots x-y points in PGPLOT using lines.
It must be registered with a tcl (or tk or [incr tcl]) int main( ) function to 
be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgline command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgline command itself).
               asArgV[0] contains "pgline", asArgV[1] contains the number of
               x-y points, asArgV[2] contains the list of x values, and 
               asArgV[3] contains the list of y values.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 Apr 17 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgline( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{


  /* Declare the local variables */
  
  int iData;         /* This is the int variable which contains the data
                        counter */
  int iNumData2;     /* This is the int variable which contains the temporary
                        version of liNumData */
  int iResult;       /* This is the int variable which contains the result of
                        "Tcl_*" function calls */
  
  integer liNumData; /* This is the integer variable which contains the number
                        of data points */
  
  real *prX;         /* This is the pointer to the 1D real array which contains
                        the x values */
  real *prY;         /* This is the pointer to the 1D real array which contains
                        the y values */
  
  char **asTclList;  /* This is the pointer to the 2D char array which contains
                        a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 4 )
  {
    pmtInterp->result = "!! Tcl_pgline: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgline( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNumData );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgline: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgline: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[2], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgline: Not enough memory...";
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgline: Invalid number of data points...";
    free( (char*) asTclList );
    return( TCL_ERROR );
  }
  
  ALLOC1( prX, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prX[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgline: Invalid x value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[3], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgline: Not enough memory...";
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgline: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  ALLOC1( prY, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prY[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgline: Invalid y value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  
  /* Call pgline( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgline( liNumData, prX, prY );
#else
  PGLINE( liNumData, prX, prY );
#endif
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prX );
  DEALLOC1( prY );
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgmove

Description:
------------
This function creates a tcl command that moves the "pen".  It must be registered
with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgmove command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgmove command itself).
               asArgV[0] contains "pgmove", asArgV[1] contains the x world
               coordinate of the line end point, and asArgV[2] contains the y
               world coordinate of the line end point.
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgmove( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult; /* This is the int variable which contains the result of "Tcl_*"
                  function calls */

  real rX;     /* This is the real variable which contains the x world
                  coordinate */
  real rY;     /* This is the real variable which contains the y world
                  coordinate */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 3 )
  {
    pmtInterp->result = "!! Tcl_pgmove: Invalid number of arguments...";
    return( TCL_ERROR );
  }


  /* Get the arguments for pgmove( ) */

  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rX );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgmove: Invalid x world coordinate...";
    return( TCL_ERROR );
  }

  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rY );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgmove: Invalid y world coordinate...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgmove( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgmove( rX, rY );
#else
  PGMOVE( rX, rY );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgmtxt

Description:
------------
This function creates a tcl command that annotates plots in PGPLOT.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgmtxt command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgmtxt command itself).
               asArgV[0] contains "pgmtxt", asArgV[1] contains the side,
               asArgV[2] contains the displacement, asArgV[3] contains the
               left coordinate, asArgV[4] contains the justification, and
               asArgV[5] contains the text.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 Jun 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgmtxt( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{


  /* Declare the local variables */
  
  int iResult;     /* This is the int variable which contains the result of
                      "Tcl_*" function calls */
  int iSide;       /* This is the int variable which contains the side name
                      element counter */
 
  real rDisp;      /* This is the real variable which contains the 
                      displacement */
  real rJust;      /* This is the real variable which contains the 
                      justification */
  real rLeftCoord; /* This is the real variable which contains the left 
                      coordinate */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 6 )
  {
    pmtInterp->result = "!! Tcl_pgmtxt: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgmtxt( ) */
  
  for ( iSide = 1; iSide <= strlen( asArgV[1] ); iSide++ )
  {
    asArgV[1][iSide - 1] = (char) toupper( (int) asArgV[1][iSide - 1] );
  }
  
  if ( strcmp( asArgV[1], "B" ) != 0 && strcmp( asArgV[1], "L" ) != 0 &&
       strcmp( asArgV[1], "T" ) != 0 && strcmp( asArgV[1], "R" ) != 0 &&
       strcmp( asArgV[1], "LV" ) != 0 && strcmp( asArgV[1], "RV" ) != 0 )
  {
    pmtInterp->result = "!! Tcl_pgmtxt: Invalid side...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rDisp );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgmtxt: Invalid displacement...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rLeftCoord );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgmtxt: Invalid left coordinate...";
    return( TCL_ERROR );
  }
    
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rJust );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgmtxt: Invalid justification...";
    return( TCL_ERROR );
  }
  
  if ( ( rJust < 0.0 ) || ( rJust > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgmtxt: Invalid justification...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgmtxt( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgmtxt( asArgV[1], rDisp, rLeftCoord, rJust, asArgV[5] );
#else
  PGMTXT( asArgV[1], rDisp, rLeftCoord, rJust, asArgV[5] );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgncur

Description:
------------
This function creates a tcl command that allows the user to mark points using
the cursor.  The points are returned in order of increasing x world coordinate.
It must be registered with a tcl (or tk or [incr tcl]) int main( ) function to
be used.

NOTE: The ordering of the arguments is slightly different from the FORTRAN call!

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgncur command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgncur command itself).
               asArgV[0] contains "pgncur", asArgV[1] contains the PGPLOT symbol
               code, asArgV[2] contains the maximum number of points to be
               entered, asArgV[3] contains the number of input points, asArgV[4]
               contains the list of x world coordinates, and asArgV[5] contains
               the list of y world coordinates.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgncur( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iNPt2;                 /* This is the int variable which contains a
				temporary version of the number of points */
  int iPt;                   /* This is the int variable which contains the
				point counter */
  int iResult;               /* This is the int variable which contains the
				result of "Tcl_*" function calls */
  
  integer liMaxPt;           /* This is the integer variable which contains the
				maximum number of points */
  integer liNPt;             /* This is the integer variable which contains the
				number of points */
  integer liSymbol;          /* This is the integer variable which contains the
				PGPLOT symbol code */

  char psTemp[100];          /* This is the pointer to the 1D char array which
				contains a temporary string */
  
  real *prX;                 /* This is the pointer to the 1D double array which
				contains the x world coordinates */
  real *prY;                 /* This is the pointer to the 1D double array which
				contains the y world coordinates */

  Tcl_Interp *pmtInterpTemp; /* This is the pointer to the Tcl_Interp variable
			        which contains a temporary tcl interpreter */
  
  char **asTclList;          /* This is the pointer to the 2D char array which
				contains a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 3 && iArgC != 6 )
  {
    pmtInterp->result = "!! Tcl_pgncur: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgncur( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liSymbol );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgncur: Invalid PGPLOT symbol flag...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[2], &liMaxPt );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgncur: Invalid maximum number of points...";
    return( TCL_ERROR );
  }
  
  if ( liMaxPt < 1 || liMaxPt > NUM_DATA_PGPLOT )
  {
    pmtInterp->result = "!! Tcl_pgncur: Invalid maximum number of points...";
    return( TCL_ERROR );
  }
  
  if ( iArgC > 3 )
  {
  
    iResult = Tcl_GetLongInt( pmtInterp, asArgV[3], &liNPt );
  
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgncur: Invalid number of points...";
      return( TCL_ERROR );
    }
  
    if ( liNPt < 1 || liNPt > liMaxPt )
    {
      pmtInterp->result = "!! Tcl_pgncur: Invalid number of points...";
      return( TCL_ERROR );
    }
    
    iResult = Tcl_SplitList( pmtInterp, asArgV[4], &iNPt2, &asTclList );
    
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgncur: Invalid list of x world coordinates...";
      free( (char*) asTclList );
      return( TCL_ERROR );
    }
    
    if ( (integer) iNPt2 != liNPt )
    {
      pmtInterp->result = "!! Tcl_pgncur: Invalid list of x world coordinates...";
      free( (char*) asTclList );
      return( TCL_ERROR );
    }
    
    ALLOC1( prX, real, ( liMaxPt - 1 ) );
    
    for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
    {
      iResult = Tcl_GetFloat( pmtInterp, asTclList[iPt], &prX[iPt] );
      if ( iResult == TCL_ERROR )
      {
        pmtInterp->result = "!! Tcl_pgncur: Invalid x world coordinate...";
        free( (char*) asTclList );
        DEALLOC1( prX );
        return( TCL_ERROR );
      }
    }
    
    free( (char*) asTclList );
    
    iResult = Tcl_SplitList( pmtInterp, asArgV[5], &iNPt2, &asTclList );
    
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgncur: Invalid list of y world coordinates...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
    
    if ( (integer) iNPt2 != liNPt )
    {
      pmtInterp->result = "!! Tcl_pgncur: Invalid list of y world coordinates...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
    
    ALLOC1( prY, real, ( liMaxPt - 1 ) );
    
    for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
    {
      iResult = Tcl_GetFloat( pmtInterp, asTclList[iPt], &prY[iPt] );
      if ( iResult == TCL_ERROR )
      {
        pmtInterp->result = "!! Tcl_pgncur: Invalid y world coordinate...";
        free( (char*) asTclList );
        DEALLOC1( prX );
        DEALLOC1( prY );
        return( TCL_ERROR );
      }
    }
  
  }
  else
  {
  
    liNPt = 0;
    
    ALLOC1( prX, real, ( liMaxPt - 1 ) );
    ALLOC1( prY, real, ( liMaxPt - 1 ) );
  
  }
  
  
  /* Call pgncur( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgncur( liMaxPt, (int*) &liNPt, (float*) &prX, (float*) &prY, liSymbol );
#else
  PGNCUR( liMaxPt, liNPt, prX, prY, liSymbol );
#endif
    
  
  /* Return liNPt, prX, prY, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liNPt );
  
  pmtInterpTemp = Tcl_CreateInterp( );
  
  for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
  {
    sprintf( psTemp, "%f", prX[iPt] );
    Tcl_AppendElement( pmtInterpTemp, psTemp );
  }
  
  Tcl_AppendElement( pmtInterp, pmtInterpTemp->result );
  Tcl_DeleteInterp( pmtInterpTemp );
  
  DEALLOC1( prX );
  
  pmtInterpTemp = Tcl_CreateInterp( );
  
  for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
  {
    sprintf( psTemp, "%f", prY[iPt] );
    Tcl_AppendElement( pmtInterpTemp, psTemp );
  }
  
  Tcl_AppendElement( pmtInterp, pmtInterpTemp->result );
  Tcl_DeleteInterp( pmtInterpTemp );
  
  DEALLOC1( prY );
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgnumb

Description:
------------
This function creates a tcl command that converts a number into its decimal
character representation.  It must be registered with a tcl (or tk or
[incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgnumb command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgnumb command itself).
               asArgV[0] contains "pgnumb", asArgV[1] contains the mantissa
               (integer), asArgV[2] contains the exponent (integer), and
               asArgV[3] contains the PGPLOT form flag.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 11 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgnumb( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;         /* This is the int variable which contains the result of
                          "Tcl_*" function calls */

  integer liForm;      /* This is the integer variable which contains the PGPLOT
                          form variable */
  integer liMM;        /* This is the integer variable which contains the
                          mantissa */
  integer liNC = 0;    /* This is the integer variable which contains the number
                          of characters in the decimal string representation */
  integer liPP;        /* This is the integer variable which contains the
                          exponent */

  char psString[1000]; /* This is the pointer to the 1D char array which
                          contains the decimal character representation */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 4 )
  {
    pmtInterp->result = "!! Tcl_pgnumb: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgnumb( ) */

  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liMM );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgnumb: Invalid mantissa...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[2], &liPP );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgnumb: Invalid exponent...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[3], &liForm );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgnumb: Invalid PGPLOT form flag...";
    return( TCL_ERROR );
  }
  
  if ( ( liForm < 0 ) || ( liForm > 2 ) )
  {
    pmtInterp->result = "!! Tcl_pgnumb: Invalid PGPLOT form flag...";
    return( TCL_ERROR );
  }

  
  /* Call pgnumb( ) */

#ifdef PGPLOT_C_WRAPPER
  liNC = sizeof( psString );
  cpgnumb( liMM, liPP, liForm, psString, (int*) &liNC );
#else
  PGNUMB( liMM, liPP, liForm, psString, liNC );
  psString[liNC] = '\0';
#endif

  
  /* Return psString, liNC, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%s %ld", psString, liNC );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgolin

Description:
------------
This function creates a tcl command that allows the user to mark points using
the cursor.  The points are returned in the order they were entered.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

NOTE: The ordering of the arguments is slightly different from the FORTRAN call!

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgolin command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgolin command itself).
               asArgV[0] contains "pgolin", asArgV[1] contains the PGPLOT symbol
               code, asArgV[2] contains the maximum number of points to be
               entered, asArgV[3] contains the number of input points, asArgV[4]
               contains the list of x world coordinates, and asArgV[5] contains
               the list of y world coordinates.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgolin( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iNPt2;                 /* This is the int variable which contains a
				temporary version of the number of points */
  int iPt;                   /* This is the int variable which contains the
				point counter */
  int iResult;               /* This is the int variable which contains the
				result of "Tcl_*" function calls */
  
  integer liMaxPt;           /* This is the integer variable which contains the
				maximum number of points */
  integer liNPt;             /* This is the integer variable which contains the
				number of points */
  integer liSymbol;          /* This is the integer variable which contains the
				PGPLOT symbol code */

  char psTemp[100];          /* This is the pointer to the 1D char array which
				contains a temporary string */
  
  real *prX;                 /* This is the pointer to the 1D double array which                                contains the x world coordinates */
  real *prY;                 /* This is the pointer to the 1D double array which
				contains the y world coordinates */

  Tcl_Interp *pmtInterpTemp; /* This is the pointer to the Tcl_Interp variable
			        which contains a temporary tcl interpreter */
  
  char **asTclList;          /* This is the pointer to the 2D char array which
				contains a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 3 && iArgC != 6 )
  {
    pmtInterp->result = "!! Tcl_pgolin: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgolin( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liSymbol );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgolin: Invalid PGPLOT symbol flag...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[2], &liMaxPt );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgolin: Invalid maximum number of points...";
    return( TCL_ERROR );
  }
  
  if ( liMaxPt < 1 || liMaxPt > NUM_DATA_PGPLOT )
  {
    pmtInterp->result = "!! Tcl_pgolin: Invalid maximum number of points...";
    return( TCL_ERROR );
  }
  
  if ( iArgC > 3 )
  {
  
    iResult = Tcl_GetLongInt( pmtInterp, asArgV[3], &liNPt );
  
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgolin: Invalid number of points...";
      return( TCL_ERROR );
    }
  
    if ( liNPt < 1 || liNPt > liMaxPt )
    {
      pmtInterp->result = "!! Tcl_pgolin: Invalid number of points...";
      return( TCL_ERROR );
    }
    
    iResult = Tcl_SplitList( pmtInterp, asArgV[4], &iNPt2, &asTclList );
    
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgolin: Invalid list of x world coordinates...";
      free( (char*) asTclList );
      return( TCL_ERROR );
    }
    
    if ( (integer) iNPt2 != liNPt )
    {
      pmtInterp->result = "!! Tcl_pgolin: Invalid list of x world coordinates...";
      free( (char*) asTclList );
      return( TCL_ERROR );
    }
    
    ALLOC1( prX, real, ( liMaxPt - 1 ) );
    
    for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
    {
      iResult = Tcl_GetFloat( pmtInterp, asTclList[iPt], &prX[iPt] );
      if ( iResult == TCL_ERROR )
      {
        pmtInterp->result = "!! Tcl_pgolin: Invalid x world coordinate...";
        free( (char*) asTclList );
        DEALLOC1( prX );
        return( TCL_ERROR );
      }
    }
    
    free( (char*) asTclList );
    
    iResult = Tcl_SplitList( pmtInterp, asArgV[5], &iNPt2, &asTclList );
    
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgolin: Invalid list of y world coordinates...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
    
    if ( (integer) iNPt2 != liNPt )
    {
      pmtInterp->result = "!! Tcl_pgolin: Invalid list of y world coordinates...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
    
    ALLOC1( prY, real, ( liMaxPt - 1 ) );
    
    for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
    {
      iResult = Tcl_GetFloat( pmtInterp, asTclList[iPt], &prY[iPt] );
      if ( iResult == TCL_ERROR )
      {
        pmtInterp->result = "!! Tcl_pgncur: Invalid y world coordinate...";
        free( (char*) asTclList );
        DEALLOC1( prX );
        DEALLOC1( prY );
        return( TCL_ERROR );
      }
    }
  
  }
  else
  {
  
    liNPt = 0;
    
    ALLOC1( prX, real, ( liMaxPt - 1 ) );
    ALLOC1( prY, real, ( liMaxPt - 1 ) );
  
  }
  
  
  /* Call pgolin( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgolin( liMaxPt, (int*) &liNPt, prX, prY, liSymbol );
#else
  PGOLIN( liMaxPt, liNPt, prX, prY, liSymbol );
#endif
    
  
  /* Return liNPt, prX, prY, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liNPt );
  
  pmtInterpTemp = Tcl_CreateInterp( );
  
  for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
  {
    sprintf( psTemp, "%f", prX[iPt] );
    Tcl_AppendElement( pmtInterpTemp, psTemp );
  }
  
  Tcl_AppendElement( pmtInterp, pmtInterpTemp->result );
  Tcl_DeleteInterp( pmtInterpTemp );
  
  DEALLOC1( prX );
  
  pmtInterpTemp = Tcl_CreateInterp( );
  
  for ( iPt = 0; iPt <= ( liNPt - 1 ); iPt++ )
  {
    sprintf( psTemp, "%f", prY[iPt] );
    Tcl_AppendElement( pmtInterpTemp, psTemp );
  }
  
  Tcl_AppendElement( pmtInterp, pmtInterpTemp->result );
  Tcl_DeleteInterp( pmtInterpTemp );
  
  DEALLOC1( prY );
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgopen

Description:
------------
This function creates a tcl command that opens a new graphics device in PGPLOT.
It must be registered with a tcl (or tk or [incr tcl]) int main( ) function to
be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgopen command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgopen command itself).
               asArgV[0] contains "pgopen" and asArgV[1] contains the device.
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1997 May 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgopen( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;       /* This is the int variable which contains the result of
                        "Tcl_*" function calls */
  
  integer liPgopen;  /* This is the integer variable which contains the pgopen
                        flag */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgopen: Invalid number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgopen( ) */

#ifdef PGPLOT_C_WRAPPER
  liPgopen = (integer) cpgopen( asArgV[1] );
#else
  liPgopen = PGOPEN( asArgV[1] );
#endif
  
  
  /* Return the pgopen flag and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liPgopen );
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgpage

Description:
------------
This function creates a tcl command that advances to the next plot in PGPLOT.  
It must be registered with a tcl (or tk or [incr tcl]) int main( ) function to 
be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgpage command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgpage command itself).
               asArgV[0] contains "pgpage".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 Apr 17 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgpage( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgpage: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgpage( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgpage( );
#else
  PGPAGE( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgpanl

Description:
------------
This function creates a tcl command that changes to a different plotting panel.
It must be registered with a tcl (or tk or [incr tcl]) int main( ) function to
be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgpanl command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgpanl command itself).
               asArgV[0] contains "pgpanl", asArgV[1] contains the panel number
               in the x direction, and asArgV[2] contains the panel number in
               the y direction.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgpanl( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;     /* This is the int variable which contains the result of
                      "Tcl_*" function calls */

  integer liNXSub; /* This is the integer variable which contains the panel
                      number in the x direction */
  integer liNYSub; /* This is the integer variable which contains the panel
                      number in the y direction */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 3 )
  {
    pmtInterp->result = "!! Tcl_pgpanl: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgpanl( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNXSub );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpanl: Invalid panel number (x direction)...";
    return( TCL_ERROR );
  }
  
  if ( liNXSub < 1 )
  {
    pmtInterp->result = "!! Tcl_pgpanl: Invalid panel number (x direction)...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[2], &liNYSub );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpanl: Invalid panel number (y direction)...";
    return( TCL_ERROR );
  }
  
  if ( liNYSub < 1 )
  {
    pmtInterp->result = "!! Tcl_pgpanl: Invalid panel number (y direction)...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgpanl( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgpanl( liNXSub, liNYSub );
#else
  PGPANL( liNXSub, liNYSub );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgpap

Description:
------------
This function creates a tcl command that changes the size of the view surface.
It must be registered with a tcl (or tk or [incr tcl]) int main( ) function to
be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgpap command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgpap command itself).
               asArgV[0] contains "pgpap", asArgV[1] contains the width, and
               asArgV[2] contains the aspect ratio.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgpap( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */

  real rAspect; /* This is the real variable which contains the aspect ratio */
  real rWidth;  /* This is the real variable which contains the width */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 3 )
  {
    pmtInterp->result = "!! Tcl_pgpap: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgpap( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rWidth );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpap: Invalid width...";
    return( TCL_ERROR );
  }
  
  if ( rWidth < 0.0 )
  {
    pmtInterp->result = "!! Tcl_pgpap: Invalid width...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rAspect );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpap: Invalid aspect ratio...";
    return( TCL_ERROR );
  }
  
  if ( rAspect <= 0.0 )
  {
    pmtInterp->result = "!! Tcl_pgpap: Invalid aspect ratio...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgpap( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgpap( rWidth, rAspect );
#else
  PGPAP( rWidth, rAspect );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgpnts

Description:
------------
This function creates a tcl command that plots x-y points in PGPLOT using 
different symbols.  It must be registered with a tcl (or tk or [incr tcl]) int
main( )  function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgpnts command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgpnts command itself).
               asArgV[0] contains "pgpnts", asArgV[1] contains the number of x-y
               points, asArgV[2] contains the list of x values, asArgV[3]
               contains the list of y values, asArgV[4] contains the list of
               PGPLOT symbol codes, and asArgV[5] contains the number of PGPLOT
               symbol codes.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgpnts( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{


  /* Declare the local variables */
  
  int iData;           /* This is the int variable which contains the data
                          counter */
  int iNumData2;       /* This is the int variable which contains the temporary
                          version of liNumData */
  int iResult;         /* This is the int variable which contains the result of
                          "Tcl_*" function calls */
  
  integer liNumData;   /* This is the integer variable which contains the number
                          of data points */
  integer liNumSymbol; /* This is the integer variable which contains the number
                          of PGPLOT symbol codes */
  
  integer *pliSymbol;  /* This is the pointer to the integer array which
                          contains the PGPLOT symbol codes */
  
  real *prX;           /* This is the pointer to the 1D real array which
                          contains the x values */
  real *prY;           /* This is the pointer to the 1D real array which
                          contains the y values */
  
  char **asTclList;    /* This is the pointer to the 2D char array which
                          contains a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 6 )
  {
    pmtInterp->result = "!! Tcl_pgpnts: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgpnts( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNumData  );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpnts: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgpnts: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[2], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpnts: Not enough memory...";
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgpnts: Invalid number of data points...";
    free( (char*) asTclList );
    return( TCL_ERROR );
  }
  
  ALLOC1( prX, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prX[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgpnts: Invalid x value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[3], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpnts: Not enough memory...";
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgpnts: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  ALLOC1( prY, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prY[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgpnts: Invalid y value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[4], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpnts: Not enough memory...";
    DEALLOC1( prX );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgpnts: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prX );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  ALLOC1( pliSymbol, integer, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetLongInt( pmtInterp, asTclList[iData], &pliSymbol[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgpnts: Invalid PGPLOT symbol code...";
      free( (char*) asTclList );
      DEALLOC1( pliSymbol );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[5], &liNumSymbol );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpnts: Invalid number of PGPLOT symbol flags...";
    DEALLOC1( pliSymbol );
    DEALLOC1( prX );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  if ( ( liNumSymbol < -1 ) || ( liNumSymbol > 127 ) )
  {
    pmtInterp->result = "!! Tcl_pgpnts: Invalid number of PGPLOT symbol flags...";
    DEALLOC1( pliSymbol );
    DEALLOC1( prX );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  
  /* Call pgpnts( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgpnts( liNumData, prX, prY, (int*) pliSymbol, liNumSymbol );
#else
  PGPNTS( liNumData, prX, prY, pliSymbol, liNumSymbol );
#endif
  
  
  /* Deallocate the memory */
  
  DEALLOC1( pliSymbol );
  
  DEALLOC1( prX );
  DEALLOC1( prY );
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgpoly

Description:
------------
This function creates a tcl command that creates a polygon and shades it.
It must be registered with a tcl (or tk or [incr tcl]) int main( ) function to
be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgpoly command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgpoly command itself).
               asArgV[0] contains "pgpoly", asArgV[1] contains the number of x-y
               points, asArgV[2] contains the list of x values, and asArgV[3]
               contains the list of y values.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 10 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgpoly( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{


  /* Declare the local variables */
  
  int iData;         /* This is the int variable which contains the data
                        counter */
  int iNumData2;     /* This is the int variable which contains the temporary
                        version of liNumData */
  int iResult;       /* This is the int variable which contains the result of
                        "Tcl_*" function calls */
  
  integer liNumData; /* This is the integer variable which contains the number
                        of data points */
  
  real *prX;         /* This is the pointer to the 1D real array which contains
                        the x values */
  real *prY;         /* This is the pointer to the 1D real array which contains
                        the y values */
  
  char **asTclList;  /* This is the pointer to the 2D char array which contains
                        a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 4 )
  {
    pmtInterp->result = "!! Tcl_pgpoly: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgpoly( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNumData  );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpoly: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgpoly: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[2], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpoly: Not enough memory...";
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgpoly: Invalid number of data points...";
    free( (char*) asTclList );
    return( TCL_ERROR );
  }
  
  ALLOC1( prX, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prX[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgpoly: Invalid x value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[3], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpoly: Not enough memory...";
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgpoly: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  ALLOC1( prY, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prY[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgpoly: Invalid y value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  
  /* Call pgpoly( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgpoly( liNumData, prX, prY );
#else
  PGPOLY( liNumData, prX, prY );
#endif
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prX );
  DEALLOC1( prY );
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgpt

Description:
------------
This function creates a tcl command that plots x-y points in PGPLOT using
symbols.  It must be registered with a tcl (or tk or [incr tcl]) int main( ) 
function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgpt command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgpt command itself).
               asArgV[0] contains "pgpt", asArgV[1] contains the number of x-y
               points, asArgV[2] contains the list of x values, asArgV[3]
               contains the list of y values, and asArgV[4] contains the PGPLOT
               symbol code.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 Apr 17 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgpt( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{


  /* Declare the local variables */
  
  int iData;         /* This is the int variable which contains the data
                        counter */
  int iNumData2;     /* This is the int variable which contains the temporary
                        version of liNumData */
  int iResult;       /* This is the int variable which contains the result of
                        "Tcl_*" function calls */
  
  integer liNumData; /* This is the integer variable which contains the number
                        of data points */
  integer liSymbol;  /* This is the integer variable which contains the PGPLOT
                        symbol code.  It must be between -1 and 127, 
                        inclusive */
  
  real *prX;         /* This is the pointer to the 1D real array which contains
                        the x values */
  real *prY;         /* This is the pointer to the 1D real array which contains
                        the y values */
  
  char **asTclList;  /* This is the pointer to the 2D char array which contains
                        a tcl list */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pgpt: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgpt( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNumData  );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpt: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  if ( ( liNumData < 1 ) || ( liNumData > iNumDataPGPLOT ) )
  {
    pmtInterp->result = "!! Tcl_pgpt: Invalid number of data points...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[2], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpt: Not enough memory...";
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgpt: Invalid number of data points...";
    free( (char*) asTclList );
    return( TCL_ERROR );
  }
  
  ALLOC1( prX, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prX[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgpt: Invalid x value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_SplitList( pmtInterp, asArgV[3], &iNumData2, &asTclList );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpt: Not enough memory...";
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  if ( ( (integer) iNumData2 ) != liNumData )
  {
    pmtInterp->result = "!! Tcl_pgpt: Invalid number of data points...";
    free( (char*) asTclList );
    DEALLOC1( prX );
    return( TCL_ERROR );
  }
  
  ALLOC1( prY, real, ( liNumData - 1 ) );
  
  for ( iData = 0; iData <= ( liNumData - 1 ); iData++ )
  {
    iResult = Tcl_GetFloat( pmtInterp, asTclList[iData], &prY[iData] );
    if ( iResult == TCL_ERROR )
    {
      pmtInterp->result = "!! Tcl_pgpt: Invalid y value...";
      free( (char*) asTclList );
      DEALLOC1( prX );
      DEALLOC1( prY );
      return( TCL_ERROR );
    }
  }
  
  free( (char*) asTclList );
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[4], &liSymbol );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgpt: Invalid PGPLOT symbol flag...";
    DEALLOC1( prX );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  if ( ( liSymbol < -1 ) || ( liSymbol > 127 ) )
  {
    pmtInterp->result = "!! Tcl_pgpt: Invalid PGPLOT symbol flag...";
    DEALLOC1( prX );
    DEALLOC1( prY );
    return( TCL_ERROR );
  }
  
  
  /* Call pgpt( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgpt( liNumData, prX, prY, liSymbol );
#else
  PGPT( liNumData, prX, prY, liSymbol );
#endif
  
  
  /* Deallocate the memory */
  
  DEALLOC1( prX );
  DEALLOC1( prY );
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgptxt

Description:
------------
This function creates a tcl command that writes text at an arbitrary location
and orientation.  It must be registered with a tcl (or tk or [incr tcl]) int
main( ) function to be used. The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgptxt command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgptxt command itself).
               asArgV[0] contains "pgptxt", asArgV[1] contains the x world
               coordinate, asArgV[2] contains the y world coordinate, asArgV[3]
               contains the angle, asArgV[4] contains the justification flag,
               and asArgV[5] contains the text.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgptxt( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */
  
  real rAngle;  /* This is the 1D real variable which contains the angle */
  real rJust;   /* This is the 1D real variable which contains the justification
                   flag */
  real rX;      /* This is the 1D real variable which contains the x world
                   coordinate */
  real rY;      /* This is the 1D real variable which contains the y world
                   coordinate */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 6 )
  {
    pmtInterp->result = "!! Tcl_pgptxt: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgptxt( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rX );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgptxt: Invalid x world coordinate...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rY );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgptxt: Invalid y world coordinate...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rAngle );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgptxt: Invalid angle...";
    return( TCL_ERROR );
  }
  
  if ( ( rAngle < 0.0 ) || ( rAngle > 360.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgptxt: Invalid angle...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rJust );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgptxt: Invalid justification flag...";
    return( TCL_ERROR );
  }
  
  if ( ( rJust < 0.0 ) || ( rJust > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgptxt: Invalid justification flag...";
    return( TCL_ERROR );
  }


  /* Call pgptxt( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgptxt( rX, rY, rAngle, rJust, asArgV[5] );
#else
  PGPTXT( rX, rY, rAngle, rJust, asArgV[5] );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqah

Description:
------------
This function creates a tcl command that queries the arrow-head style.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The fill style, acute angle, and vent angle are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqah command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqah command itself).
               asArgV[0] contains "pgqah".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 28 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqah( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  integer liFS; /* This is the integer variable which contains the fill style */
  
  real rAngle;  /* This is the real variable which contains the arrow angle */
  real rVent;   /* This is the real variable which contains the vent angle */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqah: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqah( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqah( (int*) &liFS, (float*) &rAngle, (float*) &rVent );
#else
  PGQAH( liFS, rAngle, rVent );
#endif
  
  
  /* Return liFS, rAngle, rVent, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld %f %f", liFS, rAngle, rVent );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqcf

Description:
------------
This function creates a tcl command that queries the character font.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The font number is returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqcf command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqcf command itself).
               asArgV[0] contains "pgqcf".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 28 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqcf( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  integer liFont; /* This is the integer variable which contains the font
                     number */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqcf: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqcf( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqcf( (int*) &liFont );
#else
  PGQCF( liFont );
#endif
  
  
  /* Return liFont and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liFont );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqch

Description:
------------
This function creates a tcl command that queries the character height.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The character height is returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqch command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqch command itself).
               asArgV[0] contains "pgqch".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 28 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqch( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  real rHeight; /* This is the real variable which contains the character
                   height */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqch: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqch( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqch( (float*) &rHeight );
#else
  PGQCH( rHeight );
#endif
  
  
  /* Return rHeight and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%f", rHeight );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqci

Description:
------------
This function creates a tcl command that queries the color index.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The color index is returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqci command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqci command itself).
               asArgV[0] contains "pgqci".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 28 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqci( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  integer liCI; /* This is the integer variable which contains the color
                   index */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqci: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqci( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqci( (int*) &liCI );
#else
  PGQCI( liCI );
#endif
  
  
  /* Return liCI and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liCI );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqcir

Description:
------------
This function creates a tcl command that queries the color index range.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The color index range is returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqcir command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqcir command itself).
               asArgV[0] contains "pgqcir".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 28 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqcir( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  integer liCIHigh; /* This is the integer variable which contains the maximum
                       PGPLOT color index */
  integer liCILow;  /* This is the integer variable which contains the minimum
                       PGPLOT color index */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqcir: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqcir( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqcir( (int*) &liCILow, (int*) &liCIHigh );
#else
  PGQCIR( liCILow, liCIHigh );
#endif
  
  
  /* Return liCILow, liCIHigh, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld %ld", liCILow, liCIHigh );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqcol

Description:
------------
This function creates a tcl command that queries the color capability.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqcol command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqcol command itself).
               asArgV[0] contains "pgqcol".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 28 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqcol( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  integer liCIHigh; /* This is the integer variable which contains the color
                       index maximum */
  integer liCILow;  /* This is the integer variable which contains the color
                       index minimum */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqcol: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqcol( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqcol( (int*) &liCILow, (int*) &liCIHigh );
#else
  PGQCOL( liCILow, liCIHigh );
#endif
  
  
  /* Return liCILow, liCIHigh, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld %ld", liCILow, liCIHigh );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqcr

Description:
------------
This function creates a tcl command that queries the color representation.  It
must be registered with a tcl (or tk or [incr tcl]) int main( ) function to be
used.  The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqcr command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqcr command itself).
               asArgV[0] contains "pgqcr" and asArgV[1] is the color index.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 28 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqcr( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */

  integer liCI; /* This is the integer variable which contains the color
                   index */
  
  real rCB;     /* This is the real variable which contains the blue
		   intensity */
  real rCG;     /* This is the real variable which contains the green
		   intensity */
  real rCR;     /* This is the real variable which contains the red intensity */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgqcr: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgqcr( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liCI );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgqcr: Invalid color index...";
    return( TCL_ERROR );
  }


  /* Call pgqcr( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqcr( liCI, (float*) &rCR, (float*) &rCG, (float*) &rCB );
#else
  PGQCR( liCI, rCR, rCG, rCB );
#endif
  
  
  /* Return rCR, rCG, rCB, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%f %f %f", rCR, rCG, rCB );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqcs

Description:
------------
This function creates a tcl command that queries the character height.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqcs command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqcs command itself).
               asArgV[0] contains "pgqcs" and asArgV[1] is the units flag.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqcs( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;     /* This is the int variable which contains the result of
                      "Tcl_*" function calls */
  
  integer liUnits; /* This is the integer variable which contains the PGPLOT
                      units flag */
  
  real rXCh;       /* This is the real variable which contains the character
                      height for vertically written text */
  real rYCh;       /* This is the real variable which contains the character
                      height for horizontally written text */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgqcs: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgqcs( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liUnits );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgqcs: Invalid units flag...";
    return( TCL_ERROR );
  }


  /* Call pgqcs( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqcs( liUnits, (float*) &rXCh, (float*) &rYCh );
#else
  PGQCS( liUnits, rXCh, rYCh );
#endif
  
  
  /* Return rXCh, rYCh, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%f %f", rXCh, rYCh );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqfs

Description:
------------
This function creates a tcl command that queries the fill-area style.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqfs command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqfs command itself).
               asArgV[0] contains "pgqfs".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqfs( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  integer liFS; /* This is the integer variable which contains the PGPLOT
                   fill-area style flag */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqfs: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqfs( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqfs( (int*) &liFS );
#else
  PGQFS( liFS );
#endif
  
  
  /* Return liFS and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liFS );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqhs

Description:
------------
This function creates a tcl command that queries the hatch style.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqhs command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqhs command itself).
               asArgV[0] contains "pgqhs".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1997 May 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqhs( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  real rAngle; /* This is the real variable which contains the angle the hatch
                  lines make with the horizontal */
  real rSEPN;  /* This is the real variable which contains the hatch line
                  spacing */
  real rPhase; /* This is the real variable which contains the hatch line
                  "phase" (between 0 and 1) */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqhs: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqhs( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqhs( (float*) &rAngle, (float*) &rSEPN, (float*) &rPhase );
#else
  PGQHS( rAngle, rSEPN, rPhase );
#endif
  
  
  /* Return rAngle, rSEPN, rPhase, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%f %f %f", rAngle, rSEPN, rPhase );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqid

Description:
------------
This function creates a tcl command that returns the ID of the currently
selected graphics device number in PGPLOT.  It must be registered with a tcl (or
tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqid command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqid command itself).
               asArgV[0] contains "pgqid".
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1997 May 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqid( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  integer liID; /* This is the integer variable which contains the graphics
                   device ID number */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqid: Invalid number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgqid( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqid( (int*) &liID );
#else
  PGQID( liID );
#endif
  
  
  /* Return the graphics device ID number and TCL_OK to the calling function */

  sprintf( pmtInterp->result, "%ld", liID );
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqinf

Description:
------------
This function creates a tcl command that queries PGPLOT general information.  It
must be registered with a tcl (or tk or [incr tcl]) int main( ) function to be
used.  The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqinf command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqinf command itself).
               asArgV[0] contains "pgqinf" and asArgV[1] is the query item.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqinf( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  integer liLen = 0;  /* This is the integer variable which contains the length
                         of the result string */
                     
  char psResult[100]; /* This is the pointer to the 1D char array which contains
                         the result of the query */
                     
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgqinf: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqinf( ) */

#ifdef PGPLOT_C_WRAPPER
  liLen = sizeof( psResult );
  cpgqinf( asArgV[1], psResult, (int*) &liLen );
#else
  PGQINF( asArgV[1], psResult, liLen );
  psResult[liLen] = '\0';
#endif

  
  /* Return psResult, liLen, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%s %ld", psResult, liLen );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqitf

Description:
------------
This function creates a tcl command that queries the image transfer function.
It must be registered with a tcl (or tk or [incr tcl]) int main( ) function to
be used.  The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqitf command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqitf command itself).
               asArgV[0] contains "pgqitf".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqitf( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  integer liITF; /* This is the integer variable which contains the PGPLOT image
                    transfer function flag */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqitf: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqitf( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqitf( (int*) &liITF );
#else
  PGQITF( liITF );
#endif
  
  
  /* Return liITF and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liITF );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqls

Description:
------------
This function creates a tcl command that queries the line style.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqls command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqls command itself).
               asArgV[0] contains "pgqls".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqls( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  integer liLS; /* This is the integer variable which contains the PGPLOT line
                   style flag */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqls: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqls( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqls( (int*) &liLS );
#else
  PGQLS( liLS );
#endif
  
  
  /* Return liLS and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liLS );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqlw

Description:
------------
This function creates a tcl command that queries the line width.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqlw command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqlw command itself).
               asArgV[0] contains "pgqlw".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqlw( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  integer liLW; /* This is the integer variable which contains the PGPLOT line
                   width */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqlw: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqlw( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqlw( (int*) &liLW );
#else
  PGQLW( liLW );
#endif
  
  
  /* Return liLW and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liLW );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqpos

Description:
------------
This function creates a tcl command that queries the pen position.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqpos command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqpos command itself).
               asArgV[0] contains "pgqpos".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqpos( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  real rX;     /* This is the real variable which contains the x-axis pen
                  position in world coordinates */
  real rY;     /* This is the real variable which contains the y-axis pen
                  position in world coordinates */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqpos: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqpos( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqpos( (float*) &rX, (float*) &rY );
#else
  PGQPOS( rX, rY );
#endif
  
  
  /* Return rX, rY, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%f %f", rX, rY );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqtbg

Description:
------------
This function creates a tcl command that queries the text background color
index.  It must be registered with a tcl (or tk or [incr tcl]) int main( )
function to be used.  The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqtbg command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqtbg command itself).
               asArgV[0] contains "pgqtbg".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqtbg( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  integer liTBG; /* This is the integer variable which contains the PGPLOT text
                    background color index */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqtbg: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqtbg( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqtbg( (int*) &liTBG );
#else
  PGQTBG( liTBG );
#endif
  
  
  /* Return liTBG and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liTBG );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqtxt

Description:
------------
This function creates a tcl command that queries the text bounding box.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqtxt command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqtxt command itself).
               asArgV[0] contains "pgqtxt", asArgV[1] contains the x world
               coordinate, asArgV[2] contains the y world coordinate, asArgV[3]
               contains the angle, asArgV[4] contains the justification flag,
               and asArgV[5] contains the text.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqtxt( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */
  
  real rAngle;  /* This is the real variable which contains the angle */
  real rJust;   /* This is the real variable which contains the justification
                   flag */
  real rX;      /* This is the real variable which contains the x world
                   coordinate */
  real rY;      /* This is the real variable which contains the y world
                   coordinate */
  
  real *prXBox; /* This is the pointer to the 1D real array which contains the
                   x world coordinates of the text bounding box */
  real *prYBox; /* This is the pointer to the 1D real array which contains the
                   y world coordinates of the text bounding box */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 6 )
  {
    pmtInterp->result = "!! Tcl_pgqtxt: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgqtxt( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rX );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgqtxt: Invalid x world coordinate...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rY );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgqtxt: Invalid y world coordinate...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rAngle );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgqtxt: Invalid angle...";
    return( TCL_ERROR );
  }
  
  if ( ( rAngle < 0.0 ) || ( rAngle > 360.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgqtxt: Invalid angle...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rJust );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgqtxt: Invalid justification flag...";
    return( TCL_ERROR );
  }
  
  if ( ( rJust < 0.0 ) || ( rJust > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgqtxt: Invalid justification flag...";
    return( TCL_ERROR );
  }


  /* Call pgqtxt( ) */
  
  ALLOC1( prXBox, real, ( 4 - 1 ) );
  ALLOC1( prYBox, real, ( 4 - 1 ) );

#ifdef PGPLOT_C_WRAPPER
  cpgqtxt( rX, rY, rAngle, rJust, asArgV[5], prXBox, prYBox );
#else
  PGQTXT( rX, rY, rAngle, rJust, asArgV[5], prXBox, prYBox );
#endif
  
  
  /* Return prXBox, prYBox, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "{%f %f %f %f} {%f %f %f %f}",
      prXBox[0], prXBox[1], prXBox[2], prXBox[3],
      prYBox[0], prYBox[1], prYBox[2], prYBox[3] );

  DEALLOC1( prXBox );
  DEALLOC1( prYBox );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqvp

Description:
------------
This function creates a tcl command that queries the viewport setting.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqvp command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqvp command itself).
               asArgV[0] contains "pgqvp" and asArgV[1] contains the unit flag.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqvp( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;    /* This is the int variable which contains the result of
                     "Tcl_*" function calls */

  integer liUnit; /* This is the integer variable which contains the PGPLOT unit
                     flag */

  real rX1;       /* This is the real variable which contains the first x
                     coordinate */
  real rX2;       /* This is the real variable which contains the second x
                     coordinate */
  real rY1;       /* This is the real variable which contains the first y
                     coordinate */
  real rY2;       /* This is the real variable which contains the second y
                     coordinate */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgqvp: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgqvp( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liUnit );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgqvp: Invalid unit flag...";
    return( TCL_ERROR );
  }


  /* Call pgqvp( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqvp( liUnit, (float*) &rX1, (float*) &rX2, (float*) &rY1, (float*) &rY2 );
#else
  PGQVP( liUnit, rX1, rX2, rY1, rY2 );
#endif
  
  
  /* Return rX1, rX2, rY1, rY2, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%f %f %f %f", rX1, rX2, rY1, rY2 );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqvsz

Description:
------------
This function creates a tcl command that queries the viewport size.  It must
be registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqvp command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqvp command itself).
               asArgV[0] contains "pgqvp" and asArgV[1] contains the unit flag.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqvsz( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;    /* This is the int variable which contains the result of
                     "Tcl_*" function calls */

  integer liUnit; /* This is the integer variable which contains the PGPLOT unit
                     flag */

  real rX1;       /* This is the real variable which contains the first x
                     coordinate */
  real rX2;       /* This is the real variable which contains the second x
                     coordinate */
  real rY1;       /* This is the real variable which contains the first y
                     coordinate */
  real rY2;       /* This is the real variable which contains the second y
                     coordinate */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgqvsz: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgqvsz( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liUnit );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgqvsz: Invalid unit flag...";
    return( TCL_ERROR );
  }


  /* Call pgqvsz( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqvsz( liUnit, (float*) &rX1, (float*) &rX2, (float*) &rY1, (float*) &rY2 );
#else
  PGQVSZ( liUnit, rX1, rX2, rY1, rY2 );
#endif
  
  
  /* Return rX1, rX2, rY1, rY2, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%f %f %f %f", rX1, rX2, rY1, rY2 );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgqwin

Description:
------------
This function creates a tcl command that queries the window setting.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgqwin command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgqwin command itself).
               asArgV[0] contains "pgqwin".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgqwin( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  real rX1;    /* This is the real variable which contains the first x
                  coordinate */
  real rX2;    /* This is the real variable which contains the second x
                  coordinate */
  real rY1;    /* This is the real variable which contains the first y
                  coordinate */
  real rY2;    /* This is the real variable which contains the second y
                  coordinate */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgqwin: Wrong number of arguments...";
    return( TCL_ERROR );
  }


  /* Call pgqwin( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgqwin( (float*) &rX1, (float*) &rX2, (float*) &rY1, (float*) &rY2 );
#else
  PGQWIN( rX1, rX2, rY1, rY2 );
#endif
  
  
  /* Return rX1, rX2, rY1, rY2, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%f %f %f %f", rX1, rX2, rY1, rY2 );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgrect

Description:
------------
This function creates a tcl command that draws a rectangle.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgrect command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgrect command itself).
               asArgV[0] contains "pgrect", asArgV[1] contains the first x
               coordinate, asArgV[2] contains the second x coordinate, asArgV[3]
               contains the first y coordinate, and asArgV[4] contains the
               second y coordinate.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 06 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgrect( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult; /* This is the int variable which contains the result of "Tcl_*"
                  function calls */

  real rX1;    /* This is the real variable which contains the first x world
                  coordinate */
  real rX2;    /* This is the real variable which contains the second x world
                  coordinate */
  real rY1;    /* This is the real variable which contains the first y world
                  coordinate */
  real rY2;    /* This is the real variable which contains the second y world
                  coordinate */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pgrect: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgrect( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rX1 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgrect: Invalid x world coordinate (lower left corner)...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rX2 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgrect: Invalid x world coordinate (upper right corner)...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rY1 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgrect: Invalid y world coordinate (lower left corner)...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rY2 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgrect: Invalid y world coordinate (upper right corner)...";
    return( TCL_ERROR );
  }


  /* Call pgrect( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgrect( rX1, rX2, rY1, rY2 );
#else
  PGRECT( rX1, rX2, rY1, rY2 );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgrnd

Description:
------------
This function creates a tcl command which finds the smallest rounded number
larger than the input number.  It must be registered with a tcl (or tk or
[incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgrnd command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgrnd command itself).
               asArgV[0] contains "pgrnd" and asArgV[1] contains the input
               number.
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgrnd( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;    /* This is the int variable which contains the result of
                     "Tcl_*" function calls */
  
  integer liNSub; /* This is the integer variable which contains the best
                     subdividing number */
  
  real rX;        /* This is the real variable which contains the input
                     number */
  real rXRound;   /* This is the real variable which contains the rounded
                     number */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgrnd: Invalid number of arguments...";
    return( TCL_ERROR );
  }


  /* Get the arguments for pgrnd( ) */

  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rX );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgrnd: Invalid input number...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgrnd( ) */
  
#ifdef PGPLOT_C_WRAPPER
  rXRound = (real) cpgrnd( rX, (int*) &liNSub );
#else
  rXRound = PGRND( rX, liNSub );
#endif
  
  
  /* Return rXRound, liNSub, and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%f %ld", rXRound, liNSub );
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgrnge

Description:
------------
This function creates a tcl command that determines the "best" lower and upper 
limits for an axis.  It must be registered with a tcl (or tk or [incr tcl]) int
main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgrnge command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgrnge command itself).
               asArgV[0] contains "pgrnge", asArgV[1] contains the lower limit,
               and asArgV[2] contains the upper limit.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 May 09 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgrnge( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;      /* This is the int variable which contains the result of
                       "Tcl_*" function calls */
  
  real rLow;        /* This is the real variable which contains the lower
                       limit */
  real rLowBest;    /* This is the real variable which contains the best lower
                       limit */
  real rHigh;       /* This is the real variable which contains the upper
                       limit */
  real rHighBest;   /* This is the real variable which contains the best upper
                       limit */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 3 )
  {
    pmtInterp->result = "!! Tcl_pgrnge: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgrnge( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rLow );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgrnge: Invalid lower limit...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rHigh );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgrnge: Invalid upper limit...";
    return( TCL_ERROR );
  }


  /* Call pgrnge( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgrnge( rLow, rHigh, (float*) &rLowBest, (float*) &rHighBest );
#else
  PGRNGE( rLow, rHigh, rLowBest, rHighBest );
#endif
  
  
  /* Return rLowBest, rHighBest and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%f %f", rLowBest, rHighBest );

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgsah

Description:
------------
This function creates a tcl command that sets the arrowhead style.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgsah command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgsah command itself).
               asArgV[0] contains "pgsah", asArgV[1] is the fill style flag,
               asArgV[2] is the arrow point angle, and asArgV[3] is the arrow
               point cut-away fraction.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 07 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgsah( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;   /* This is the int variable which contains the result of
                    "Tcl_*" function calls */
  
  integer liFS; /* This is the integer variable which contains the PGPLOT fill
                   style flag */
  
  real rAngle;  /* This is the real variable which contains the arrow point
                   angle (degrees) */
  real rVent;   /* This is the real variable which contains the arrow cut-away
                   fraction */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 4 )
  {
    pmtInterp->result = "!! Tcl_pgsah: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgsah( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liFS );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsah: Invalid fill style flag...";
    return( TCL_ERROR );
  }
  
  if ( ( liFS != 1 ) && ( liFS != 2 ) )
  {
    pmtInterp->result = "!! Tcl_pgsah: Invalid fill style flag...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rAngle );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsah: Invalid arrow point angle...";
    return( TCL_ERROR );
  }
  
  if ( ( rAngle < 0.0 ) || ( rAngle > 90.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgsah: Invalid arrow point angle...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rVent );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsah: Invalid arrow point cut-away fraction...";
    return( TCL_ERROR );
  }
  
  if ( ( rVent < 0.0 ) || ( rVent > 90.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgsah: Invalid arrow point cut-away fraction...";
    return( TCL_ERROR );
  }


  /* Call pgsah( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgsah( liFS, rAngle, rVent );
#else
  PGSAH( liFS, rAngle, rVent );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgsave

Description:
------------
This function creates a tcl command that saves the current PGPLOT attributes on
a FIFO stack (up to 20 elements).  It must be registered with a tcl (or tk or
[incr tcl]) int main( ) function to  be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgsave command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgsave command itself).
               asArgV[0] contains "pgsave".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 12 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgsave( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgsave: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgsave( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgsave( );
#else
  PGSAVE( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgscf

Description:
------------
This function creates a tcl command that changes the font for subsequent
characters.  The font index must be between 1 and 4.  It must be registered with
a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgscf command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgscf command itself).
               asArgV[0] contains "pgscf" and asArgV[1] contains the font index.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 04 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgscf( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;    /* This is the int variable which contains the result of
                     "Tcl_*" function calls */
  
  integer liFont; /* This is the integer variable which contains the PGPLOT
                     font number */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgscf: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgscf( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liFont );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgscf: Invalid font index...";
    return( TCL_ERROR );
  }
  
  if ( ( liFont < 1 ) || ( liFont > 4 ) )
  {
    pmtInterp->result = "!! Tcl_pgscf: Invalid font index...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgscf( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgscf( liFont );
#else
  PGSCF( liFont );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgsch

Description:
------------
This function creates a tcl command that changes the height for subsequent
characters.  The height is a multiple of the default length (1/40 the height of
the view surface).  It must be registered with a tcl (or tk or [incr tcl]) int
main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgsch command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgsch command itself).
               asArgV[0] contains "pgsch" and asArgV[1] contains the height.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 04 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgsch( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */
  
  real rHeight; /* This is the integer variable which contains the PGPLOT
                   height */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgsch: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgsch( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rHeight );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsch: Invalid height...";
    return( TCL_ERROR );
  }
  
  if ( rHeight < 0.0 )
  {
    pmtInterp->result = "!! Tcl_pgsch: Invalid height...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgsch( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgsch( rHeight );
#else
  PGSCH( rHeight );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgsci

Description:
------------
This function creates a tcl command that changes the color for subsequent
points/curves.  The color index must be between 0 and 255.  It must be 
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgsci command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgsci command itself).
               asArgV[0] contains "pgsci" and asArgV[1] contains the color 
               index.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1994 May 07 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgsci( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */
  
  integer liCI; /* This is the integer variable which contains the PGPLOT color
                   index */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgsci: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgsci( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liCI );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsci: Invalid color index...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgsci( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgsci( liCI );
#else
  PGSCI( liCI );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgscir

Description:
------------
This function creates a tcl command that changes the color for subsequent
images.  The color indices must be between 0 and 255.  It must be registered
with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgscir command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgscir command itself).
               asArgV[0] contains "pgscir", asArgV[1] contains the low color 
               index, and asArgV[2] contains the high color index.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 07 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgscir( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;      /* This is the int variable which contains the result of
                       "Tcl_*" function calls */
  
  integer liCIHigh; /* This is the integer variable which contains the maximum
                       PGPLOT color index */
  integer liCILow;  /* This is the integer variable which contains the minimum
                       PGPLOT color index */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 3 )
  {
    pmtInterp->result = "!! Tcl_pgscir: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgscir( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liCILow );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgscir: Invalid color index (low)...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[2], &liCIHigh );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgscir: Invalid color index (high)...";
    return( TCL_ERROR );
  }
  
  if ( liCILow > liCIHigh )
  {
    pmtInterp->result = "!! Tcl_pgscir: Invalid color indices...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgscir( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgscir( liCILow, liCIHigh );
#else
  PGSCIR( liCILow, liCIHigh );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgscr

Description:
------------
This function creates a tcl command that changes the color representation.  The
color index must be between 0 and 255.  It must be registered with a tcl (or tk
or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgscr command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgscr command itself).
               asArgV[0] contains "pgscr", asArgV[1] contains the color index,
               asArgV[2] contains the red intensity, asArgV[3] contains the
               green intensity, and asArgV[4] contains the blue intensity.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 07 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgscr( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */
  
  integer liCI; /* This is the integer variable which contains the PGPLOT color
                   index */

  real rCB;     /* This is the real variable which contains the normalized blue
                   intensity */
  real rCG;     /* This is the real variable which contains the normalized green
                   intensity */
  real rCR;     /* This is the real variable which contains the normalized red
                   intensity */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pgscr: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgscr( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liCI );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgscr: Invalid color index...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rCR );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgscr: Invalid red intensity...";
    return( TCL_ERROR );
  }
  
  if ( ( rCR < 0.0 ) || ( rCR > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgscr: Invalid red intensity...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rCG );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgscr: Invalid green intensity...";
    return( TCL_ERROR );
  }
  
  if ( ( rCG < 0.0 ) || ( rCG > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgscr: Invalid green intensity...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rCB );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgscr: Invalid blue intensity...";
    return( TCL_ERROR );
  }
  
  if ( ( rCB < 0.0 ) || ( rCB > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgscr: Invalid blue intensity...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgscr( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgscr( liCI, rCR, rCG, rCB );
#else
  PGSCR( liCI, rCR, rCG, rCB );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgscrn

Description:
------------
This function creates a tcl command that changes the color representation by
name.  The color index must be between 0 and 255.  It must be registered with a
tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgscr command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgscr command itself).
               asArgV[0] contains "pgscrn", asArgV[1] contains the color index,
               and asArgV[2] contains the color name.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 07 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgscrn( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;     /* This is the int variable which contains the result of
                      "Tcl_*" function calls */
  
  integer liCI;    /* This is the integer variable which contains the PGPLOT
                      color index */
  integer liError; /* This is the integer variable which contains the PGPLOT
                      error flag */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 3 )
  {
    pmtInterp->result = "!! Tcl_pgscrn: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgscrn( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liCI );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgscrn: Invalid color index...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgscrn( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgscrn( liCI, asArgV[2], (int*) &liError );
#else
  PGSCRN( liCI, asArgV[2], liError );
#endif
    
  
  /* Return liError and TCL_OK to the calling function */
  
  sprintf( pmtInterp->result, "%ld", liError );
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgsfs

Description:
------------
This function creates a tcl command that sets the fill-area style.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgsfs command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgsfs command itself).
               asArgV[0] contains "pgsfs" and asArgV[1] contains the fill-area
               style.
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgsfs( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */

  integer liFS; /* This is the integer variable which contains the fill-area
                   style */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgsfs: Invalid number of arguments...";
    return( TCL_ERROR );
  }


  /* Get the arguments for pgsfs( ) */

  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liFS );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsfs: Invalid fill-area style...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgsfs( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgsfs( liFS );
#else
  PGSFS( liFS );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgshls

Description:
------------
This function creates a tcl command that changes the color representation with
the HLS system.  The color index must be between 0 and 255.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgshls command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgshls command itself).
               asArgV[0] contains "pgshls", asArgV[1] contains the color index,
               asArgV[2] contains the hue, asArgV[3] contains the lightness, and
               asArgV[4] contains the saturation.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 07 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgshls( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */
  
  integer liCI; /* This is the integer variable which contains the PGPLOT color
                   index */

  real rCH;     /* This is the real variable which contains the hue */
  real rCL;     /* This is the real variable which contains the lightness */
  real rCS;     /* This is the real variable which contains the saturation */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pgshls: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgshls( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liCI );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pghls: Invalid color index...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rCH );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgshls: Invalid hue...";
    return( TCL_ERROR );
  }
  
  if ( ( rCH < 0.0 ) || ( rCH > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgshls: Invalid hue...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rCL );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgshls: Invalid lightness...";
    return( TCL_ERROR );
  }
  
  if ( ( rCL < 0.0 ) || ( rCL > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgshls: Invalid lightness...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rCS );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgshls: Invalid saturation...";
    return( TCL_ERROR );
  }
  
  if ( ( rCS < 0.0 ) || ( rCS > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgshls: Invalid saturation...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgshls( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgshls( liCI, rCH, rCL, rCS );
#else
  PGSHLS( liCI, rCH, rCL, rCS );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgshs

Description:
------------
This function creates a tcl command that sets the hatch style.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgshs command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgshs command itself).
               asArgV[0] contains "pgshs", asArgV[1] contains the angle the
               hatch lines make with the horizontal, asArgV[2] contains the
               hatch line spacing, and asArgV[3] contains the hatch line phase.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1997 May 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgshs( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult; /* This is the int variable which contains the result of "Tcl_*"
                  function calls */
  
  real rAngle; /* This is the real variable which contains the angle the hatch
                  lines make with the horizontal */
  real rSEPN;  /* This is the real variable which contains the hatch line
                  spacing */
  real rPhase; /* This is the real variable which contains the hatch line
                  "phase" (between 0 and 1) */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 4 )
  {
    pmtInterp->result = "!! Tcl_pgshs: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgshs( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rAngle );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgshs: Invalid hatch angle...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rSEPN );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgshs: Invalid hatch spacing...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rPhase );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgshs: Invalid hatch phase...";
    return( TCL_ERROR );
  }
  
  if ( rPhase < 0.0 || rPhase > 1.0 )
  {
    pmtInterp->result = "!! Tcl_pgshs: Invalid hatch phase...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgshs( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgshs( rAngle, rSEPN, rPhase );
#else
  PGSHS( rAngle, rSEPN, rPhase );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgsitf

Description:
------------
This function creates a tcl command that changes the image transfer function for
subsequent images.  The image transfer function index must be between 0 and 2.
It must be registered with a tcl (or tk or [incr tcl]) int main( ) function to
be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgsitf command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgsitf command itself).
               asArgV[0] contains "pgsitf" and asArgV[1] contains the image
               transfer function index.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 04 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgsitf( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;   /* This is the int variable which contains the result of
                    "Tcl_*" function calls */
  
  integer liITF; /* This is the integer variable which contains the PGPLOT image
                    transfer function flag */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgsitf: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgsitf( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liITF );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsitf: Invalid image transfer function index...";
    return( TCL_ERROR );
  }
  
  if ( ( liITF < 0 ) || ( liITF > 2 ) )
  {
    pmtInterp->result = "!! Tcl_pgsitf: Invalid image transfer function index...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgsitf( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgsitf( liITF );
#else
  PGSITF( liITF );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgslct

Description:
------------
This function creates a tcl command that selects an open graphics device in
PGPLOT.  It must be registered with a tcl (or tk or [incr tcl]) int main( )
function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgslct command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgslct command itself).
               asArgV[0] contains "pgslct" and asArgV[1] contains the graphics
               device ID number.
               
Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1997 May 03 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgslct( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */

  integer liID; /* This is the integer variable which contains the graphics
                   device ID number */
  
  
  /* Check to see if the number of arguments is correct */

  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgslct: Invalid number of arguments...";
    return( TCL_ERROR );
  }


  /* Get the argument for pgslct( ) */

  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liID );

  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgslct: Invalid graphics device ID number...";
    return( TCL_ERROR );
  }
  
  if ( liID < 1 )
  {
    pmtInterp->result = "!! Tcl_pgslct: Invalid graphics device ID number...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgslct( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgslct( liID );
#else
  PGSLCT( liID );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgsls

Description:
------------
This function creates a tcl command that changes the line style for subsequent
plots.  The line style index must be between 1 and 5.  It must be registered
with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgsls command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgsls command itself).
               asArgV[0] contains "pgsls" and asArgV[1] contains the line style
               index.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 04 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgsls( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */
  
  integer liLS; /* This is the integer variable which contains the PGPLOT line
                   style flag */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgsls: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgsls( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liLS );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsls: Invalid line style index...";
    return( TCL_ERROR );
  }
  
  if ( ( liLS < 1 ) || ( liLS > 5 ) )
  {
    pmtInterp->result = "!! Tcl_pgsls: Invalid line style index...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgsls( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgsls( liLS );
#else
  PGSLS( liLS );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgslw

Description:
------------
This function creates a tcl command that changes the line width for subsequent
plots.  The line width must be an integer between 1 and 201 (multiples of
1/200").  It must be registered with a tcl (or tk or [incr tcl]) int main( )
function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgslw command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgslw command itself).
               asArgV[0] contains "pgslw" and asArgV[1] contains the line width.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 04 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgslw( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;  /* This is the int variable which contains the result of
                   "Tcl_*" function calls */
  
  integer liLW; /* This is the integer variable which contains the PGPLOT line
                   width */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgslw: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgslw( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liLW );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgslw: Invalid line width...";
    return( TCL_ERROR );
  }
  
  if ( ( liLW < 1 ) || ( liLW > 201 ) )
  {
    pmtInterp->result = "!! Tcl_pgslw: Invalid line width...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgslw( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgslw( liLW );
#else
  PGSLW( liLW );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgstbg

Description:
------------
This function creates a tcl command that changes the text background color for
subsequent characters.  The text background color index must be an integer.  It
must be registered with a tcl (or tk or [incr tcl]) int main( ) function to be
used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgstbg command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgstbg command itself).
               asArgV[0] contains "pgstbg" and asArgV[1] contains the text
               background color index.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 04 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgstbg( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;   /* This is the int variable which contains the result of
                    "Tcl_*" function calls */
  
  integer liTBG; /* This is the integer variable which contains the PGPLOT text
                    background color index */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 2 )
  {
    pmtInterp->result = "!! Tcl_pgstbg: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgstbg( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liTBG );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgstbg: Invalid text background color index...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgstbg( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgstbg( liTBG );
#else
  PGSTBG( liTBG );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgsubp

Description:
------------
This function creates a tcl command that subdivides the view surface into
panels.  The text background color index must be an integer.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgsubp command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgsubp command itself).
               asArgV[0] contains "pgsupb", asArgV[1] contains the number of
               subpanels in the x direction, and asArgV[2] contains the number
               of subpanels in the y direction.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 07 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgsubp( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;     /* This is the int variable which contains the result of
                      "Tcl_*" function calls */

  integer liNXSub; /* This is the integer variable which contains the number of
                      subpanels in the x direction */
  integer liNYSub; /* This is the integer variable which contains the number of
                      subpanels in the y direction */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 3 )
  {
    pmtInterp->result = "!! Tcl_pgsubp: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgsubp( ) */
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[1], &liNXSub );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsubp: Invalid number of subpanels (x direction)...";
    return( TCL_ERROR );
  }
  
  if ( liNXSub < 1 )
  {
    pmtInterp->result = "!! Tcl_pgsubp: Invalid number of subpanels (x direction)...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[2], &liNYSub );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsubp: Invalid number of subpanels (y direction)...";
    return( TCL_ERROR );
  }
  
  if ( liNYSub < 1 )
  {
    pmtInterp->result = "!! Tcl_pgsubp: Invalid number of subpanels (y direction)...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgsubp( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgsubp( liNXSub, liNYSub );
#else
  PGSUBP( liNXSub, liNYSub );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgsvp

Description:
------------
This function creates a tcl command that sets the viewport size.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgsvp command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgsvp command itself).
               asArgV[0] contains "pgsvp", asArgV[1] contains the left x
               normalized coordinate, asArgV[2] contains the right x normalized
               coordinate, asArgV[3] contains the bottom y normalized
               coordinate, and asArgV[4] contains the top y normalized
               coordinate.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 07 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgsvp( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;    /* This is the int variable which contains the result of
                     "Tcl_*" function calls */

  real rX1;       /* This is the real variable which contains the first x
                     coordinate */
  real rX2;       /* This is the real variable which contains the second x
                     coordinate */
  real rY1;       /* This is the real variable which contains the first y
                     coordinate */
  real rY2;       /* This is the real variable which contains the second y
                     coordinate */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pgsvp: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgsvp( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rX1 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsvp: Invalid left x coordinate...";
    return( TCL_ERROR );
  }
  
  if ( ( rX1 < 0.0 ) || ( rX1 > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgsvp: Invalid left x coordinate...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rX2 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsvp: Invalid right x coordinate...";
    return( TCL_ERROR );
  }
  
  if ( ( rX2 < 0.0 ) || ( rX2 > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgsvp: Invalid right x coordinate...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rY1 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsvp: Invalid bottom y coordinate...";
    return( TCL_ERROR );
  }
  
  if ( ( rY1 < 0.0 ) || ( rY1 > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgsvp: Invalid bottom y coordinate...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rY2 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgsvp: Invalid top y coordinate...";
    return( TCL_ERROR );
  }
  
  if ( ( rY2 < 0.0 ) || ( rY2 > 1.0 ) )
  {
    pmtInterp->result = "!! Tcl_pgsvp: Invalid top y coordinate...";
    return( TCL_ERROR );
  }


  /* Call pgsvp( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgsvp( rX1, rX2, rY1, rY2 );
#else
  PGSVP( rX1, rX2, rY1, rY2 );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgswin

Description:
------------
This function creates a tcl command that sets the window size.  It must be
registered with a tcl (or tk or [incr tcl]) int main( ) function to be used.
The minimum and maximum color indices are returned.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgswin command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgswin command itself).
               asArgV[0] contains "pgswin", asArgV[1] contains the left x world
               coordinate, asArgV[2] contains the right x world coordinate,
               asArgV[3] contains the bottom y world coordinate, and asArgV[4]
               contains the top y world coordinate.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 07 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgswin( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;    /* This is the int variable which contains the result of
                     "Tcl_*" function calls */

  real rX1;       /* This is the real variable which contains the first x
                     coordinate */
  real rX2;       /* This is the real variable which contains the second x
                     coordinate */
  real rY1;       /* This is the real variable which contains the first y
                     coordinate */
  real rY2;       /* This is the real variable which contains the second y
                     coordinate */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pgswin: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgswin( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rX1 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgswin: Invalid left x coordinate...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rX2 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgswin: Invalid right x coordinate...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rY1 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgswin: Invalid bottom y coordinate...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rY2 );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgswin: Invalid top y coordinate...";
    return( TCL_ERROR );
  }


  /* Call pgswin( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgswin( rX1, rX2, rY1, rY2 );
#else
  PGSWIN( rX1, rX2, rY1, rY2 );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgtbox

Description:
------------
This function creates a tcl command that labels one or both axes of a plot in
HH MM SS format.  It must be registered with a tcl (or tk or [incr tcl]) int
main( ) function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgtbox command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgtbox command itself).
               asArgV[0] contains "pgtbox", asArgV[1] contains the x options,
               asArgV[2] contains the x major tick increment, asArgV[3] contains
               the number of x minor ticks, asArgV[4] contains the y options,
               asArgV[5] contains the y major tick increment, and asArgV[6]
               contains the number of y minor ticks.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 11 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgtbox( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;     /* This is the int variable which contains the result of
                      "Tcl_*" function calls */

  integer liNXSub; /* This is the integer variable which contains the number of
                      x minor ticks */
  integer liNYSub; /* This is the integer variable which contains the number of
                      y minor ticks */
  
  real rXTick;     /* This is the real variable which contains the x major tick
                      increment */
  real rYTick;     /* This is the real variable which contains the y major tick
                      increment */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 7 )
  {
    pmtInterp->result = "!! Tcl_pgtbox: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgtbox( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rXTick );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgtbox: Invalid major tick increment (x direction)...";
    return( TCL_ERROR );
  }
  
  if ( rXTick < 0.0 )
  {
    pmtInterp->result = "!! Tcl_pgtbox: Invalid major tick increment (x direction)...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[3], &liNXSub );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgtbox: Invalid number of minor ticks (x direction)...";
    return( TCL_ERROR );
  }
  
  if ( liNXSub < 1 )
  {
    pmtInterp->result = "!! Tcl_pgtbox: Invalid number of minor ticks (x direction)...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[5], &rYTick );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgtbox: Invalid major tick increment (y direction)...";
    return( TCL_ERROR );
  }
  
  if ( rYTick < 0.0 )
  {
    pmtInterp->result = "!! Tcl_pgtbox: Invalid major tick increment (y direction)...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetLongInt( pmtInterp, asArgV[6], &liNYSub );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgtbox: Invalid number of minor ticks (y direction)...";
    return( TCL_ERROR );
  }
  
  if ( liNYSub < 1 )
  {
    pmtInterp->result = "!! Tcl_pgtbox: Invalid number of minor ticks (y direction)...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgtbox( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgtbox( asArgV[1], rXTick, liNXSub, asArgV[4], rYTick, liNYSub );
#else
  PGTBOX( asArgV[1], rXTick, liNXSub, asArgV[4], rYTick, liNYSub );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgtext

Description:
------------
This function creates a tcl command that writes horizontal, left-justified text.
It must be registered with a tcl (or tk or [incr tcl]) int main( ) function to
be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgtext command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgtext command itself).
               asArgV[0] contains "pgtext", asArgV[1] contains the x world
               coordinate, asArgV[2] contains the y world coordinate, and
               asArgV[3] contains the text.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 11 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgtext( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */
  
  real rX;      /* This is the 1D real variable which contains the x world
                   coordinate */
  real rY;      /* This is the 1D real variable which contains the y world
                   coordinate */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 4 )
  {
    pmtInterp->result = "!! Tcl_pgtext: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgtext( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rX );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgtext: Invalid x world coordinate...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rY );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgtext: Invalid y world coordinate...";
    return( TCL_ERROR );
  }


  /* Call pgtext( ) */

#ifdef PGPLOT_C_WRAPPER
  cpgtext( rX, rY, asArgV[3] );
#else
  PGTEXT( rX, rY, asArgV[3] );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";

  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgunsa

Description:
------------
This function creates a tcl command that gets the current PGPLOT attributes from
a FIFO stack (up to 20 elements).  It must be registered with a tcl (or tk or
[incr tcl]) int main( ) function to  be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgunsa command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgunsa command itself).
               asArgV[0] contains "pgunsa".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 12 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgunsa( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgunsa: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgunsa( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgunsa( );
#else
  PGUNSA( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgupdt

Description:
------------
This function creates a tcl command that flushes all pending PGPLOT commands to
the output device.  It must be registered with a tcl (or tk or [incr tcl]) int
main( ) function to  be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgupdt command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgupdt command itself).
               asArgV[0] contains "pgupdt".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Aug 12 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgupdt( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC,
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgupdt: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgupdt( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgupdt( );
#else
  PGUPDT( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgvsiz

Description:
------------
This function creates a tcl command that changes the size and position of the
viewport.  It must be registered with a tcl (or tk or [incr tcl]) int main( )
function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgvsiz command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgvsiz command itself).
               asArgV[0] contains "pgvsiz", asArgV[1] contains the x coordinate
               of the left edge, asArgV[2] contains the x coordinate of the
               right edge, asArgV[3] contains the y coordinate of the left edge,
               and asArgV[4] contains the y coordinate of the right edge.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 11 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgvsiz( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */
  
  int iResult;  /* This is the int variable which contains the result of "Tcl_*"
                   function calls */

  real rXLeft;  /* This is the real variable which contains the x coordinate of
                   the left edge */
  real rXRight; /* This is the real variable which contains the x coordinate of
                   the right edge */
  real rYLeft;  /* This is the real variable which contains the y coordinate of
                   the left edge */
  real rYRight; /* This is the real variable which contains the y coordinate of
                   the right edge */
                            
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pgvsiz: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgvsiz( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rXLeft );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgvsiz: Invalid x coordinate for the left edge...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rXRight );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgvsiz: Invalid x coordinate for the right edge...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rYLeft );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgvsiz: Invalid y coordinate for the left edge...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rYRight );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgvsiz: Invalid y coordinate for the right edge...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgvsiz( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgvsiz( rXLeft, rXRight, rYLeft, rYRight );
#else
  PGVSIZ( rXLeft, rXRight, rYLeft, rYRight );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgvstd

Description:
------------
This function creates a tcl command that sets the viewport to the standard
viewport.  It must be registered with a tcl (or tk or [incr tcl]) int main( )
function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgvstd command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgvstd command itself).
               asArgV[0] contains "pgvstd".

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 Nov 11 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgvstd( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 1 )
  {
    pmtInterp->result = "!! Tcl_pgvstd: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Call pgvstd( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgvstd( );
#else
  PGVSTD( );
#endif
    
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}

/* -------------------------------------------------------------------------- */

/*

Tcl_pgwnad

Description:
------------
This function creates a tcl command that sets the window and adjusts the
viewport.  It must be registered with a tcl (or tk or [incr tcl]) int main( )
function to be used.

Inputs:
-------
mtClientData - This is a ClientData structure used to pass a one-word value to 
               this command procedure (not actually used in this procedure).
iArgC        - This is the int variable which contains the number of arguments 
               (including the pgwnad command itself) on the tcl command line.
**asArgV     - This is the pointer to the 2D char array which contains the tcl 
               command line arguments (including the pgwnad command itself).
               asArgV[0] contains "pgwnad", asArgV[1] contains the x-axis lower 
               limit, asArgV[2] contains the x-axis upper limit, asArgV[3]
               contains the y-axis lower limit, and asArgV[4] contains the
               y-axis.

Outputs:
--------
*pmtInterp - This is the pointer to the Tcl_Interp structure which contains the
             tcl interpreter information.

Modification history:
---------------------
1995 May 02 - Nicholas Elias, USNO/AD5
              Function created.

*/

/* -------------------------------------------------------------------------- */

int Tcl_pgwnad( ClientData mtClientData, Tcl_Interp *pmtInterp, int iArgC, 
    char **asArgV )
{

  /* Declare the local variables */

  int iResult;     /* This is the int variable which contains the result of
                      "Tcl_*" function calls */
  
  real rXAxisLow;  /* This is the real variable which contains the x axis lower
                      limit */
  real rXAxisHigh; /* This is the real variable which contains the x axis upper
                      limit */
  real rYAxisLow;  /* This is the real variable which contains the y axis lower
                      limit */
  real rYAxisHigh; /* This is the real variable which contains the y axis upper
                      limit */
  
  
  /* Check to see if the number of arguments is correct */
  
  if ( iArgC != 5 )
  {
    pmtInterp->result = "!! Tcl_pgwnad: Wrong number of arguments...";
    return( TCL_ERROR );
  }
  
  
  /* Get the arguments for pgwnad( ) */
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[1], &rXAxisLow );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgwnad: Invalid x-axis lower limit...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[2], &rXAxisHigh );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgwnad: Invalid x-axis upper limit...";
    return( TCL_ERROR );
  }
  
  if ( rXAxisLow >= rXAxisHigh )
  {
    pmtInterp->result = "!! Tcl_pgwnad: Invalid x-axis limits...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[3], &rYAxisLow );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgwnad: Invalid y-axis lower limit...";
    return( TCL_ERROR );
  }
  
  iResult = Tcl_GetFloat( pmtInterp, asArgV[4], &rYAxisHigh );
  
  if ( iResult == TCL_ERROR )
  {
    pmtInterp->result = "!! Tcl_pgwnad: Invalid y-axis upper limit...";
    return( TCL_ERROR );
  }
  
  if ( rYAxisLow >= rYAxisHigh )
  {
    pmtInterp->result = "!! Tcl_pgwnad: Invalid y-axis limits...";
    return( TCL_ERROR );
  }

  
  /* Call pgwnad( ) */
  
#ifdef PGPLOT_C_WRAPPER
  cpgwnad( rXAxisLow, rXAxisHigh, rYAxisLow, rYAxisHigh );
#else
  PGWNAD( rXAxisLow, rXAxisHigh, rYAxisLow, rYAxisHigh );
#endif
  
  
  /* Return "" and TCL_OK to the calling function */

  pmtInterp->result = "";
  
  return( TCL_OK );
  
}
